// Code generated by protoc-gen-go. DO NOT EDIT.
// source: google/cloud/automl/v1beta1/service.proto

package automl

import (
	context "context"
	fmt "fmt"
	math "math"

	proto "github.com/golang/protobuf/proto"
	_ "google.golang.org/genproto/googleapis/api/annotations"
	longrunning "google.golang.org/genproto/googleapis/longrunning"
	field_mask "google.golang.org/genproto/protobuf/field_mask"
	grpc "google.golang.org/grpc"
)

// Reference imports to suppress errors if they are not otherwise used.
var _ = proto.Marshal
var _ = fmt.Errorf
var _ = math.Inf

// This is a compile-time assertion to ensure that this generated file
// is compatible with the proto package it is being compiled against.
// A compilation error at this line likely means your copy of the
// proto package needs to be updated.
const _ = proto.ProtoPackageIsVersion3 // please upgrade the proto package

// Request message for [AutoMl.CreateDataset][google.cloud.automl.v1beta1.AutoMl.CreateDataset].
type CreateDatasetRequest struct {
	// The resource name of the project to create the dataset for.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// The dataset to create.
	Dataset              *Dataset `protobuf:"bytes,2,opt,name=dataset,proto3" json:"dataset,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CreateDatasetRequest) Reset()         { *m = CreateDatasetRequest{} }
func (m *CreateDatasetRequest) String() string { return proto.CompactTextString(m) }
func (*CreateDatasetRequest) ProtoMessage()    {}
func (*CreateDatasetRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{0}
}

func (m *CreateDatasetRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateDatasetRequest.Unmarshal(m, b)
}
func (m *CreateDatasetRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateDatasetRequest.Marshal(b, m, deterministic)
}
func (m *CreateDatasetRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateDatasetRequest.Merge(m, src)
}
func (m *CreateDatasetRequest) XXX_Size() int {
	return xxx_messageInfo_CreateDatasetRequest.Size(m)
}
func (m *CreateDatasetRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateDatasetRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CreateDatasetRequest proto.InternalMessageInfo

func (m *CreateDatasetRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *CreateDatasetRequest) GetDataset() *Dataset {
	if m != nil {
		return m.Dataset
	}
	return nil
}

// Request message for [AutoMl.GetDataset][google.cloud.automl.v1beta1.AutoMl.GetDataset].
type GetDatasetRequest struct {
	// The resource name of the dataset to retrieve.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetDatasetRequest) Reset()         { *m = GetDatasetRequest{} }
func (m *GetDatasetRequest) String() string { return proto.CompactTextString(m) }
func (*GetDatasetRequest) ProtoMessage()    {}
func (*GetDatasetRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{1}
}

func (m *GetDatasetRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetDatasetRequest.Unmarshal(m, b)
}
func (m *GetDatasetRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetDatasetRequest.Marshal(b, m, deterministic)
}
func (m *GetDatasetRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetDatasetRequest.Merge(m, src)
}
func (m *GetDatasetRequest) XXX_Size() int {
	return xxx_messageInfo_GetDatasetRequest.Size(m)
}
func (m *GetDatasetRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetDatasetRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetDatasetRequest proto.InternalMessageInfo

func (m *GetDatasetRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request message for [AutoMl.ListDatasets][google.cloud.automl.v1beta1.AutoMl.ListDatasets].
type ListDatasetsRequest struct {
	// The resource name of the project from which to list datasets.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// An expression for filtering the results of the request.
	//
	//   * `dataset_metadata` - for existence of the case (e.g.
	//             image_classification_dataset_metadata:*). Some examples of using the filter are:
	//
	//   * `translation_dataset_metadata:*` --> The dataset has
	//                                          translation_dataset_metadata.
	Filter string `protobuf:"bytes,3,opt,name=filter,proto3" json:"filter,omitempty"`
	// Requested page size. Server may return fewer results than requested.
	// If unspecified, server will pick a default size.
	PageSize int32 `protobuf:"varint,4,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// A token identifying a page of results for the server to return
	// Typically obtained via
	// [ListDatasetsResponse.next_page_token][google.cloud.automl.v1beta1.ListDatasetsResponse.next_page_token] of the previous
	// [AutoMl.ListDatasets][google.cloud.automl.v1beta1.AutoMl.ListDatasets] call.
	PageToken            string   `protobuf:"bytes,6,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListDatasetsRequest) Reset()         { *m = ListDatasetsRequest{} }
func (m *ListDatasetsRequest) String() string { return proto.CompactTextString(m) }
func (*ListDatasetsRequest) ProtoMessage()    {}
func (*ListDatasetsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{2}
}

func (m *ListDatasetsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListDatasetsRequest.Unmarshal(m, b)
}
func (m *ListDatasetsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListDatasetsRequest.Marshal(b, m, deterministic)
}
func (m *ListDatasetsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListDatasetsRequest.Merge(m, src)
}
func (m *ListDatasetsRequest) XXX_Size() int {
	return xxx_messageInfo_ListDatasetsRequest.Size(m)
}
func (m *ListDatasetsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListDatasetsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListDatasetsRequest proto.InternalMessageInfo

func (m *ListDatasetsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListDatasetsRequest) GetFilter() string {
	if m != nil {
		return m.Filter
	}
	return ""
}

func (m *ListDatasetsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

func (m *ListDatasetsRequest) GetPageToken() string {
	if m != nil {
		return m.PageToken
	}
	return ""
}

// Response message for [AutoMl.ListDatasets][google.cloud.automl.v1beta1.AutoMl.ListDatasets].
type ListDatasetsResponse struct {
	// The datasets read.
	Datasets []*Dataset `protobuf:"bytes,1,rep,name=datasets,proto3" json:"datasets,omitempty"`
	// A token to retrieve next page of results.
	// Pass to [ListDatasetsRequest.page_token][google.cloud.automl.v1beta1.ListDatasetsRequest.page_token] to obtain that page.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListDatasetsResponse) Reset()         { *m = ListDatasetsResponse{} }
func (m *ListDatasetsResponse) String() string { return proto.CompactTextString(m) }
func (*ListDatasetsResponse) ProtoMessage()    {}
func (*ListDatasetsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{3}
}

func (m *ListDatasetsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListDatasetsResponse.Unmarshal(m, b)
}
func (m *ListDatasetsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListDatasetsResponse.Marshal(b, m, deterministic)
}
func (m *ListDatasetsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListDatasetsResponse.Merge(m, src)
}
func (m *ListDatasetsResponse) XXX_Size() int {
	return xxx_messageInfo_ListDatasetsResponse.Size(m)
}
func (m *ListDatasetsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListDatasetsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListDatasetsResponse proto.InternalMessageInfo

func (m *ListDatasetsResponse) GetDatasets() []*Dataset {
	if m != nil {
		return m.Datasets
	}
	return nil
}

func (m *ListDatasetsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

// Request message for [AutoMl.UpdateDataset][google.cloud.automl.v1beta1.AutoMl.UpdateDataset]
type UpdateDatasetRequest struct {
	// The dataset which replaces the resource on the server.
	Dataset *Dataset `protobuf:"bytes,1,opt,name=dataset,proto3" json:"dataset,omitempty"`
	// The update mask applies to the resource. For the `FieldMask` definition,
	// see
	//
	// https:
	// //developers.google.com/protocol-buffers
	// // /docs/reference/google.protobuf#fieldmask
	UpdateMask           *field_mask.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *UpdateDatasetRequest) Reset()         { *m = UpdateDatasetRequest{} }
func (m *UpdateDatasetRequest) String() string { return proto.CompactTextString(m) }
func (*UpdateDatasetRequest) ProtoMessage()    {}
func (*UpdateDatasetRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{4}
}

func (m *UpdateDatasetRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_UpdateDatasetRequest.Unmarshal(m, b)
}
func (m *UpdateDatasetRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_UpdateDatasetRequest.Marshal(b, m, deterministic)
}
func (m *UpdateDatasetRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_UpdateDatasetRequest.Merge(m, src)
}
func (m *UpdateDatasetRequest) XXX_Size() int {
	return xxx_messageInfo_UpdateDatasetRequest.Size(m)
}
func (m *UpdateDatasetRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_UpdateDatasetRequest.DiscardUnknown(m)
}

var xxx_messageInfo_UpdateDatasetRequest proto.InternalMessageInfo

func (m *UpdateDatasetRequest) GetDataset() *Dataset {
	if m != nil {
		return m.Dataset
	}
	return nil
}

func (m *UpdateDatasetRequest) GetUpdateMask() *field_mask.FieldMask {
	if m != nil {
		return m.UpdateMask
	}
	return nil
}

// Request message for [AutoMl.DeleteDataset][google.cloud.automl.v1beta1.AutoMl.DeleteDataset].
type DeleteDatasetRequest struct {
	// The resource name of the dataset to delete.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *DeleteDatasetRequest) Reset()         { *m = DeleteDatasetRequest{} }
func (m *DeleteDatasetRequest) String() string { return proto.CompactTextString(m) }
func (*DeleteDatasetRequest) ProtoMessage()    {}
func (*DeleteDatasetRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{5}
}

func (m *DeleteDatasetRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_DeleteDatasetRequest.Unmarshal(m, b)
}
func (m *DeleteDatasetRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_DeleteDatasetRequest.Marshal(b, m, deterministic)
}
func (m *DeleteDatasetRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_DeleteDatasetRequest.Merge(m, src)
}
func (m *DeleteDatasetRequest) XXX_Size() int {
	return xxx_messageInfo_DeleteDatasetRequest.Size(m)
}
func (m *DeleteDatasetRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_DeleteDatasetRequest.DiscardUnknown(m)
}

var xxx_messageInfo_DeleteDatasetRequest proto.InternalMessageInfo

func (m *DeleteDatasetRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request message for [AutoMl.ImportData][google.cloud.automl.v1beta1.AutoMl.ImportData].
type ImportDataRequest struct {
	// Required. Dataset name. Dataset must already exist. All imported
	// annotations and examples will be added.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The desired input location and its domain specific semantics,
	// if any.
	InputConfig          *InputConfig `protobuf:"bytes,3,opt,name=input_config,json=inputConfig,proto3" json:"input_config,omitempty"`
	XXX_NoUnkeyedLiteral struct{}     `json:"-"`
	XXX_unrecognized     []byte       `json:"-"`
	XXX_sizecache        int32        `json:"-"`
}

func (m *ImportDataRequest) Reset()         { *m = ImportDataRequest{} }
func (m *ImportDataRequest) String() string { return proto.CompactTextString(m) }
func (*ImportDataRequest) ProtoMessage()    {}
func (*ImportDataRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{6}
}

func (m *ImportDataRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ImportDataRequest.Unmarshal(m, b)
}
func (m *ImportDataRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ImportDataRequest.Marshal(b, m, deterministic)
}
func (m *ImportDataRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ImportDataRequest.Merge(m, src)
}
func (m *ImportDataRequest) XXX_Size() int {
	return xxx_messageInfo_ImportDataRequest.Size(m)
}
func (m *ImportDataRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ImportDataRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ImportDataRequest proto.InternalMessageInfo

func (m *ImportDataRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *ImportDataRequest) GetInputConfig() *InputConfig {
	if m != nil {
		return m.InputConfig
	}
	return nil
}

// Request message for [AutoMl.ExportData][google.cloud.automl.v1beta1.AutoMl.ExportData].
type ExportDataRequest struct {
	// Required. The resource name of the dataset.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The desired output location.
	OutputConfig         *OutputConfig `protobuf:"bytes,3,opt,name=output_config,json=outputConfig,proto3" json:"output_config,omitempty"`
	XXX_NoUnkeyedLiteral struct{}      `json:"-"`
	XXX_unrecognized     []byte        `json:"-"`
	XXX_sizecache        int32         `json:"-"`
}

func (m *ExportDataRequest) Reset()         { *m = ExportDataRequest{} }
func (m *ExportDataRequest) String() string { return proto.CompactTextString(m) }
func (*ExportDataRequest) ProtoMessage()    {}
func (*ExportDataRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{7}
}

func (m *ExportDataRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ExportDataRequest.Unmarshal(m, b)
}
func (m *ExportDataRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ExportDataRequest.Marshal(b, m, deterministic)
}
func (m *ExportDataRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ExportDataRequest.Merge(m, src)
}
func (m *ExportDataRequest) XXX_Size() int {
	return xxx_messageInfo_ExportDataRequest.Size(m)
}
func (m *ExportDataRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ExportDataRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ExportDataRequest proto.InternalMessageInfo

func (m *ExportDataRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *ExportDataRequest) GetOutputConfig() *OutputConfig {
	if m != nil {
		return m.OutputConfig
	}
	return nil
}

// Request message for [AutoMl.GetAnnotationSpec][google.cloud.automl.v1beta1.AutoMl.GetAnnotationSpec].
type GetAnnotationSpecRequest struct {
	// The resource name of the annotation spec to retrieve.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetAnnotationSpecRequest) Reset()         { *m = GetAnnotationSpecRequest{} }
func (m *GetAnnotationSpecRequest) String() string { return proto.CompactTextString(m) }
func (*GetAnnotationSpecRequest) ProtoMessage()    {}
func (*GetAnnotationSpecRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{8}
}

func (m *GetAnnotationSpecRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetAnnotationSpecRequest.Unmarshal(m, b)
}
func (m *GetAnnotationSpecRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetAnnotationSpecRequest.Marshal(b, m, deterministic)
}
func (m *GetAnnotationSpecRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetAnnotationSpecRequest.Merge(m, src)
}
func (m *GetAnnotationSpecRequest) XXX_Size() int {
	return xxx_messageInfo_GetAnnotationSpecRequest.Size(m)
}
func (m *GetAnnotationSpecRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetAnnotationSpecRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetAnnotationSpecRequest proto.InternalMessageInfo

func (m *GetAnnotationSpecRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request message for [AutoMl.GetTableSpec][google.cloud.automl.v1beta1.AutoMl.GetTableSpec].
type GetTableSpecRequest struct {
	// The resource name of the table spec to retrieve.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Mask specifying which fields to read.
	FieldMask            *field_mask.FieldMask `protobuf:"bytes,2,opt,name=field_mask,json=fieldMask,proto3" json:"field_mask,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *GetTableSpecRequest) Reset()         { *m = GetTableSpecRequest{} }
func (m *GetTableSpecRequest) String() string { return proto.CompactTextString(m) }
func (*GetTableSpecRequest) ProtoMessage()    {}
func (*GetTableSpecRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{9}
}

func (m *GetTableSpecRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetTableSpecRequest.Unmarshal(m, b)
}
func (m *GetTableSpecRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetTableSpecRequest.Marshal(b, m, deterministic)
}
func (m *GetTableSpecRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetTableSpecRequest.Merge(m, src)
}
func (m *GetTableSpecRequest) XXX_Size() int {
	return xxx_messageInfo_GetTableSpecRequest.Size(m)
}
func (m *GetTableSpecRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetTableSpecRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetTableSpecRequest proto.InternalMessageInfo

func (m *GetTableSpecRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *GetTableSpecRequest) GetFieldMask() *field_mask.FieldMask {
	if m != nil {
		return m.FieldMask
	}
	return nil
}

// Request message for [AutoMl.ListTableSpecs][google.cloud.automl.v1beta1.AutoMl.ListTableSpecs].
type ListTableSpecsRequest struct {
	// The resource name of the dataset to list table specs from.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Mask specifying which fields to read.
	FieldMask *field_mask.FieldMask `protobuf:"bytes,2,opt,name=field_mask,json=fieldMask,proto3" json:"field_mask,omitempty"`
	// Filter expression, see go/filtering.
	Filter string `protobuf:"bytes,3,opt,name=filter,proto3" json:"filter,omitempty"`
	// Requested page size. The server can return fewer results than requested.
	// If unspecified, the server will pick a default size.
	PageSize int32 `protobuf:"varint,4,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// A token identifying a page of results for the server to return.
	// Typically obtained from the
	// [ListTableSpecsResponse.next_page_token][google.cloud.automl.v1beta1.ListTableSpecsResponse.next_page_token] field of the previous
	// [AutoMl.ListTableSpecs][google.cloud.automl.v1beta1.AutoMl.ListTableSpecs] call.
	PageToken            string   `protobuf:"bytes,6,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListTableSpecsRequest) Reset()         { *m = ListTableSpecsRequest{} }
func (m *ListTableSpecsRequest) String() string { return proto.CompactTextString(m) }
func (*ListTableSpecsRequest) ProtoMessage()    {}
func (*ListTableSpecsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{10}
}

func (m *ListTableSpecsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListTableSpecsRequest.Unmarshal(m, b)
}
func (m *ListTableSpecsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListTableSpecsRequest.Marshal(b, m, deterministic)
}
func (m *ListTableSpecsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListTableSpecsRequest.Merge(m, src)
}
func (m *ListTableSpecsRequest) XXX_Size() int {
	return xxx_messageInfo_ListTableSpecsRequest.Size(m)
}
func (m *ListTableSpecsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListTableSpecsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListTableSpecsRequest proto.InternalMessageInfo

func (m *ListTableSpecsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListTableSpecsRequest) GetFieldMask() *field_mask.FieldMask {
	if m != nil {
		return m.FieldMask
	}
	return nil
}

func (m *ListTableSpecsRequest) GetFilter() string {
	if m != nil {
		return m.Filter
	}
	return ""
}

func (m *ListTableSpecsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

func (m *ListTableSpecsRequest) GetPageToken() string {
	if m != nil {
		return m.PageToken
	}
	return ""
}

// Response message for [AutoMl.ListTableSpecs][google.cloud.automl.v1beta1.AutoMl.ListTableSpecs].
type ListTableSpecsResponse struct {
	// The table specs read.
	TableSpecs []*TableSpec `protobuf:"bytes,1,rep,name=table_specs,json=tableSpecs,proto3" json:"table_specs,omitempty"`
	// A token to retrieve next page of results.
	// Pass to [ListTableSpecsRequest.page_token][google.cloud.automl.v1beta1.ListTableSpecsRequest.page_token] to obtain that page.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListTableSpecsResponse) Reset()         { *m = ListTableSpecsResponse{} }
func (m *ListTableSpecsResponse) String() string { return proto.CompactTextString(m) }
func (*ListTableSpecsResponse) ProtoMessage()    {}
func (*ListTableSpecsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{11}
}

func (m *ListTableSpecsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListTableSpecsResponse.Unmarshal(m, b)
}
func (m *ListTableSpecsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListTableSpecsResponse.Marshal(b, m, deterministic)
}
func (m *ListTableSpecsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListTableSpecsResponse.Merge(m, src)
}
func (m *ListTableSpecsResponse) XXX_Size() int {
	return xxx_messageInfo_ListTableSpecsResponse.Size(m)
}
func (m *ListTableSpecsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListTableSpecsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListTableSpecsResponse proto.InternalMessageInfo

func (m *ListTableSpecsResponse) GetTableSpecs() []*TableSpec {
	if m != nil {
		return m.TableSpecs
	}
	return nil
}

func (m *ListTableSpecsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

// Request message for [AutoMl.UpdateTableSpec][google.cloud.automl.v1beta1.AutoMl.UpdateTableSpec]
type UpdateTableSpecRequest struct {
	// The table spec which replaces the resource on the server.
	TableSpec *TableSpec `protobuf:"bytes,1,opt,name=table_spec,json=tableSpec,proto3" json:"table_spec,omitempty"`
	// The update mask applies to the resource. For the `FieldMask` definition,
	// see
	//
	// https:
	// //developers.google.com/protocol-buffers
	// // /docs/reference/google.protobuf#fieldmask
	UpdateMask           *field_mask.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *UpdateTableSpecRequest) Reset()         { *m = UpdateTableSpecRequest{} }
func (m *UpdateTableSpecRequest) String() string { return proto.CompactTextString(m) }
func (*UpdateTableSpecRequest) ProtoMessage()    {}
func (*UpdateTableSpecRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{12}
}

func (m *UpdateTableSpecRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_UpdateTableSpecRequest.Unmarshal(m, b)
}
func (m *UpdateTableSpecRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_UpdateTableSpecRequest.Marshal(b, m, deterministic)
}
func (m *UpdateTableSpecRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_UpdateTableSpecRequest.Merge(m, src)
}
func (m *UpdateTableSpecRequest) XXX_Size() int {
	return xxx_messageInfo_UpdateTableSpecRequest.Size(m)
}
func (m *UpdateTableSpecRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_UpdateTableSpecRequest.DiscardUnknown(m)
}

var xxx_messageInfo_UpdateTableSpecRequest proto.InternalMessageInfo

func (m *UpdateTableSpecRequest) GetTableSpec() *TableSpec {
	if m != nil {
		return m.TableSpec
	}
	return nil
}

func (m *UpdateTableSpecRequest) GetUpdateMask() *field_mask.FieldMask {
	if m != nil {
		return m.UpdateMask
	}
	return nil
}

// Request message for [AutoMl.GetColumnSpec][google.cloud.automl.v1beta1.AutoMl.GetColumnSpec].
type GetColumnSpecRequest struct {
	// The resource name of the column spec to retrieve.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Mask specifying which fields to read.
	FieldMask            *field_mask.FieldMask `protobuf:"bytes,2,opt,name=field_mask,json=fieldMask,proto3" json:"field_mask,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *GetColumnSpecRequest) Reset()         { *m = GetColumnSpecRequest{} }
func (m *GetColumnSpecRequest) String() string { return proto.CompactTextString(m) }
func (*GetColumnSpecRequest) ProtoMessage()    {}
func (*GetColumnSpecRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{13}
}

func (m *GetColumnSpecRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetColumnSpecRequest.Unmarshal(m, b)
}
func (m *GetColumnSpecRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetColumnSpecRequest.Marshal(b, m, deterministic)
}
func (m *GetColumnSpecRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetColumnSpecRequest.Merge(m, src)
}
func (m *GetColumnSpecRequest) XXX_Size() int {
	return xxx_messageInfo_GetColumnSpecRequest.Size(m)
}
func (m *GetColumnSpecRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetColumnSpecRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetColumnSpecRequest proto.InternalMessageInfo

func (m *GetColumnSpecRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *GetColumnSpecRequest) GetFieldMask() *field_mask.FieldMask {
	if m != nil {
		return m.FieldMask
	}
	return nil
}

// Request message for [AutoMl.ListColumnSpecs][google.cloud.automl.v1beta1.AutoMl.ListColumnSpecs].
type ListColumnSpecsRequest struct {
	// The resource name of the table spec to list column specs from.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// Mask specifying which fields to read.
	FieldMask *field_mask.FieldMask `protobuf:"bytes,2,opt,name=field_mask,json=fieldMask,proto3" json:"field_mask,omitempty"`
	// Filter expression, see go/filtering.
	Filter string `protobuf:"bytes,3,opt,name=filter,proto3" json:"filter,omitempty"`
	// Requested page size. The server can return fewer results than requested.
	// If unspecified, the server will pick a default size.
	PageSize int32 `protobuf:"varint,4,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// A token identifying a page of results for the server to return.
	// Typically obtained from the
	// [ListColumnSpecsResponse.next_page_token][google.cloud.automl.v1beta1.ListColumnSpecsResponse.next_page_token] field of the previous
	// [AutoMl.ListColumnSpecs][google.cloud.automl.v1beta1.AutoMl.ListColumnSpecs] call.
	PageToken            string   `protobuf:"bytes,6,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListColumnSpecsRequest) Reset()         { *m = ListColumnSpecsRequest{} }
func (m *ListColumnSpecsRequest) String() string { return proto.CompactTextString(m) }
func (*ListColumnSpecsRequest) ProtoMessage()    {}
func (*ListColumnSpecsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{14}
}

func (m *ListColumnSpecsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListColumnSpecsRequest.Unmarshal(m, b)
}
func (m *ListColumnSpecsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListColumnSpecsRequest.Marshal(b, m, deterministic)
}
func (m *ListColumnSpecsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListColumnSpecsRequest.Merge(m, src)
}
func (m *ListColumnSpecsRequest) XXX_Size() int {
	return xxx_messageInfo_ListColumnSpecsRequest.Size(m)
}
func (m *ListColumnSpecsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListColumnSpecsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListColumnSpecsRequest proto.InternalMessageInfo

func (m *ListColumnSpecsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListColumnSpecsRequest) GetFieldMask() *field_mask.FieldMask {
	if m != nil {
		return m.FieldMask
	}
	return nil
}

func (m *ListColumnSpecsRequest) GetFilter() string {
	if m != nil {
		return m.Filter
	}
	return ""
}

func (m *ListColumnSpecsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

func (m *ListColumnSpecsRequest) GetPageToken() string {
	if m != nil {
		return m.PageToken
	}
	return ""
}

// Response message for [AutoMl.ListColumnSpecs][google.cloud.automl.v1beta1.AutoMl.ListColumnSpecs].
type ListColumnSpecsResponse struct {
	// The column specs read.
	ColumnSpecs []*ColumnSpec `protobuf:"bytes,1,rep,name=column_specs,json=columnSpecs,proto3" json:"column_specs,omitempty"`
	// A token to retrieve next page of results.
	// Pass to [ListColumnSpecsRequest.page_token][google.cloud.automl.v1beta1.ListColumnSpecsRequest.page_token] to obtain that page.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListColumnSpecsResponse) Reset()         { *m = ListColumnSpecsResponse{} }
func (m *ListColumnSpecsResponse) String() string { return proto.CompactTextString(m) }
func (*ListColumnSpecsResponse) ProtoMessage()    {}
func (*ListColumnSpecsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{15}
}

func (m *ListColumnSpecsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListColumnSpecsResponse.Unmarshal(m, b)
}
func (m *ListColumnSpecsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListColumnSpecsResponse.Marshal(b, m, deterministic)
}
func (m *ListColumnSpecsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListColumnSpecsResponse.Merge(m, src)
}
func (m *ListColumnSpecsResponse) XXX_Size() int {
	return xxx_messageInfo_ListColumnSpecsResponse.Size(m)
}
func (m *ListColumnSpecsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListColumnSpecsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListColumnSpecsResponse proto.InternalMessageInfo

func (m *ListColumnSpecsResponse) GetColumnSpecs() []*ColumnSpec {
	if m != nil {
		return m.ColumnSpecs
	}
	return nil
}

func (m *ListColumnSpecsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

// Request message for [AutoMl.UpdateColumnSpec][google.cloud.automl.v1beta1.AutoMl.UpdateColumnSpec]
type UpdateColumnSpecRequest struct {
	// The column spec which replaces the resource on the server.
	ColumnSpec *ColumnSpec `protobuf:"bytes,1,opt,name=column_spec,json=columnSpec,proto3" json:"column_spec,omitempty"`
	// The update mask applies to the resource. For the `FieldMask` definition,
	// see
	//
	// https:
	// //developers.google.com/protocol-buffers
	// // /docs/reference/google.protobuf#fieldmask
	UpdateMask           *field_mask.FieldMask `protobuf:"bytes,2,opt,name=update_mask,json=updateMask,proto3" json:"update_mask,omitempty"`
	XXX_NoUnkeyedLiteral struct{}              `json:"-"`
	XXX_unrecognized     []byte                `json:"-"`
	XXX_sizecache        int32                 `json:"-"`
}

func (m *UpdateColumnSpecRequest) Reset()         { *m = UpdateColumnSpecRequest{} }
func (m *UpdateColumnSpecRequest) String() string { return proto.CompactTextString(m) }
func (*UpdateColumnSpecRequest) ProtoMessage()    {}
func (*UpdateColumnSpecRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{16}
}

func (m *UpdateColumnSpecRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_UpdateColumnSpecRequest.Unmarshal(m, b)
}
func (m *UpdateColumnSpecRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_UpdateColumnSpecRequest.Marshal(b, m, deterministic)
}
func (m *UpdateColumnSpecRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_UpdateColumnSpecRequest.Merge(m, src)
}
func (m *UpdateColumnSpecRequest) XXX_Size() int {
	return xxx_messageInfo_UpdateColumnSpecRequest.Size(m)
}
func (m *UpdateColumnSpecRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_UpdateColumnSpecRequest.DiscardUnknown(m)
}

var xxx_messageInfo_UpdateColumnSpecRequest proto.InternalMessageInfo

func (m *UpdateColumnSpecRequest) GetColumnSpec() *ColumnSpec {
	if m != nil {
		return m.ColumnSpec
	}
	return nil
}

func (m *UpdateColumnSpecRequest) GetUpdateMask() *field_mask.FieldMask {
	if m != nil {
		return m.UpdateMask
	}
	return nil
}

// Request message for [AutoMl.CreateModel][google.cloud.automl.v1beta1.AutoMl.CreateModel].
type CreateModelRequest struct {
	// Resource name of the parent project where the model is being created.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// The model to create.
	Model                *Model   `protobuf:"bytes,4,opt,name=model,proto3" json:"model,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *CreateModelRequest) Reset()         { *m = CreateModelRequest{} }
func (m *CreateModelRequest) String() string { return proto.CompactTextString(m) }
func (*CreateModelRequest) ProtoMessage()    {}
func (*CreateModelRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{17}
}

func (m *CreateModelRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_CreateModelRequest.Unmarshal(m, b)
}
func (m *CreateModelRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_CreateModelRequest.Marshal(b, m, deterministic)
}
func (m *CreateModelRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_CreateModelRequest.Merge(m, src)
}
func (m *CreateModelRequest) XXX_Size() int {
	return xxx_messageInfo_CreateModelRequest.Size(m)
}
func (m *CreateModelRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_CreateModelRequest.DiscardUnknown(m)
}

var xxx_messageInfo_CreateModelRequest proto.InternalMessageInfo

func (m *CreateModelRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *CreateModelRequest) GetModel() *Model {
	if m != nil {
		return m.Model
	}
	return nil
}

// Request message for [AutoMl.GetModel][google.cloud.automl.v1beta1.AutoMl.GetModel].
type GetModelRequest struct {
	// Resource name of the model.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetModelRequest) Reset()         { *m = GetModelRequest{} }
func (m *GetModelRequest) String() string { return proto.CompactTextString(m) }
func (*GetModelRequest) ProtoMessage()    {}
func (*GetModelRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{18}
}

func (m *GetModelRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetModelRequest.Unmarshal(m, b)
}
func (m *GetModelRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetModelRequest.Marshal(b, m, deterministic)
}
func (m *GetModelRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetModelRequest.Merge(m, src)
}
func (m *GetModelRequest) XXX_Size() int {
	return xxx_messageInfo_GetModelRequest.Size(m)
}
func (m *GetModelRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetModelRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetModelRequest proto.InternalMessageInfo

func (m *GetModelRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request message for [AutoMl.ListModels][google.cloud.automl.v1beta1.AutoMl.ListModels].
type ListModelsRequest struct {
	// Resource name of the project, from which to list the models.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// An expression for filtering the results of the request.
	//
	//   * `model_metadata` - for existence of the case (e.g.
	//             video_classification_model_metadata:*).
	//   * `dataset_id` - for = or !=. Some examples of using the filter are:
	//
	//   * `image_classification_model_metadata:*` --> The model has
	//                                        image_classification_model_metadata.
	//   * `dataset_id=5` --> The model was created from a dataset with ID 5.
	Filter string `protobuf:"bytes,3,opt,name=filter,proto3" json:"filter,omitempty"`
	// Requested page size.
	PageSize int32 `protobuf:"varint,4,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// A token identifying a page of results for the server to return
	// Typically obtained via
	// [ListModelsResponse.next_page_token][google.cloud.automl.v1beta1.ListModelsResponse.next_page_token] of the previous
	// [AutoMl.ListModels][google.cloud.automl.v1beta1.AutoMl.ListModels] call.
	PageToken            string   `protobuf:"bytes,6,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListModelsRequest) Reset()         { *m = ListModelsRequest{} }
func (m *ListModelsRequest) String() string { return proto.CompactTextString(m) }
func (*ListModelsRequest) ProtoMessage()    {}
func (*ListModelsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{19}
}

func (m *ListModelsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListModelsRequest.Unmarshal(m, b)
}
func (m *ListModelsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListModelsRequest.Marshal(b, m, deterministic)
}
func (m *ListModelsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListModelsRequest.Merge(m, src)
}
func (m *ListModelsRequest) XXX_Size() int {
	return xxx_messageInfo_ListModelsRequest.Size(m)
}
func (m *ListModelsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListModelsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListModelsRequest proto.InternalMessageInfo

func (m *ListModelsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListModelsRequest) GetFilter() string {
	if m != nil {
		return m.Filter
	}
	return ""
}

func (m *ListModelsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

func (m *ListModelsRequest) GetPageToken() string {
	if m != nil {
		return m.PageToken
	}
	return ""
}

// Response message for [AutoMl.ListModels][google.cloud.automl.v1beta1.AutoMl.ListModels].
type ListModelsResponse struct {
	// List of models in the requested page.
	Model []*Model `protobuf:"bytes,1,rep,name=model,proto3" json:"model,omitempty"`
	// A token to retrieve next page of results.
	// Pass to [ListModelsRequest.page_token][google.cloud.automl.v1beta1.ListModelsRequest.page_token] to obtain that page.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListModelsResponse) Reset()         { *m = ListModelsResponse{} }
func (m *ListModelsResponse) String() string { return proto.CompactTextString(m) }
func (*ListModelsResponse) ProtoMessage()    {}
func (*ListModelsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{20}
}

func (m *ListModelsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListModelsResponse.Unmarshal(m, b)
}
func (m *ListModelsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListModelsResponse.Marshal(b, m, deterministic)
}
func (m *ListModelsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListModelsResponse.Merge(m, src)
}
func (m *ListModelsResponse) XXX_Size() int {
	return xxx_messageInfo_ListModelsResponse.Size(m)
}
func (m *ListModelsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListModelsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListModelsResponse proto.InternalMessageInfo

func (m *ListModelsResponse) GetModel() []*Model {
	if m != nil {
		return m.Model
	}
	return nil
}

func (m *ListModelsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

// Request message for [AutoMl.DeleteModel][google.cloud.automl.v1beta1.AutoMl.DeleteModel].
type DeleteModelRequest struct {
	// Resource name of the model being deleted.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *DeleteModelRequest) Reset()         { *m = DeleteModelRequest{} }
func (m *DeleteModelRequest) String() string { return proto.CompactTextString(m) }
func (*DeleteModelRequest) ProtoMessage()    {}
func (*DeleteModelRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{21}
}

func (m *DeleteModelRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_DeleteModelRequest.Unmarshal(m, b)
}
func (m *DeleteModelRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_DeleteModelRequest.Marshal(b, m, deterministic)
}
func (m *DeleteModelRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_DeleteModelRequest.Merge(m, src)
}
func (m *DeleteModelRequest) XXX_Size() int {
	return xxx_messageInfo_DeleteModelRequest.Size(m)
}
func (m *DeleteModelRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_DeleteModelRequest.DiscardUnknown(m)
}

var xxx_messageInfo_DeleteModelRequest proto.InternalMessageInfo

func (m *DeleteModelRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request message for [AutoMl.DeployModel][google.cloud.automl.v1beta1.AutoMl.DeployModel].
type DeployModelRequest struct {
	// The per-domain specific deployment parameters.
	//
	// Types that are valid to be assigned to ModelDeploymentMetadata:
	//	*DeployModelRequest_ImageObjectDetectionModelDeploymentMetadata
	ModelDeploymentMetadata isDeployModelRequest_ModelDeploymentMetadata `protobuf_oneof:"model_deployment_metadata"`
	// Resource name of the model to deploy.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *DeployModelRequest) Reset()         { *m = DeployModelRequest{} }
func (m *DeployModelRequest) String() string { return proto.CompactTextString(m) }
func (*DeployModelRequest) ProtoMessage()    {}
func (*DeployModelRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{22}
}

func (m *DeployModelRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_DeployModelRequest.Unmarshal(m, b)
}
func (m *DeployModelRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_DeployModelRequest.Marshal(b, m, deterministic)
}
func (m *DeployModelRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_DeployModelRequest.Merge(m, src)
}
func (m *DeployModelRequest) XXX_Size() int {
	return xxx_messageInfo_DeployModelRequest.Size(m)
}
func (m *DeployModelRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_DeployModelRequest.DiscardUnknown(m)
}

var xxx_messageInfo_DeployModelRequest proto.InternalMessageInfo

type isDeployModelRequest_ModelDeploymentMetadata interface {
	isDeployModelRequest_ModelDeploymentMetadata()
}

type DeployModelRequest_ImageObjectDetectionModelDeploymentMetadata struct {
	ImageObjectDetectionModelDeploymentMetadata *ImageObjectDetectionModelDeploymentMetadata `protobuf:"bytes,2,opt,name=image_object_detection_model_deployment_metadata,json=imageObjectDetectionModelDeploymentMetadata,proto3,oneof"`
}

func (*DeployModelRequest_ImageObjectDetectionModelDeploymentMetadata) isDeployModelRequest_ModelDeploymentMetadata() {
}

func (m *DeployModelRequest) GetModelDeploymentMetadata() isDeployModelRequest_ModelDeploymentMetadata {
	if m != nil {
		return m.ModelDeploymentMetadata
	}
	return nil
}

func (m *DeployModelRequest) GetImageObjectDetectionModelDeploymentMetadata() *ImageObjectDetectionModelDeploymentMetadata {
	if x, ok := m.GetModelDeploymentMetadata().(*DeployModelRequest_ImageObjectDetectionModelDeploymentMetadata); ok {
		return x.ImageObjectDetectionModelDeploymentMetadata
	}
	return nil
}

func (m *DeployModelRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// XXX_OneofWrappers is for the internal use of the proto package.
func (*DeployModelRequest) XXX_OneofWrappers() []interface{} {
	return []interface{}{
		(*DeployModelRequest_ImageObjectDetectionModelDeploymentMetadata)(nil),
	}
}

// Request message for [AutoMl.UndeployModel][google.cloud.automl.v1beta1.AutoMl.UndeployModel].
type UndeployModelRequest struct {
	// Resource name of the model to undeploy.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *UndeployModelRequest) Reset()         { *m = UndeployModelRequest{} }
func (m *UndeployModelRequest) String() string { return proto.CompactTextString(m) }
func (*UndeployModelRequest) ProtoMessage()    {}
func (*UndeployModelRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{23}
}

func (m *UndeployModelRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_UndeployModelRequest.Unmarshal(m, b)
}
func (m *UndeployModelRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_UndeployModelRequest.Marshal(b, m, deterministic)
}
func (m *UndeployModelRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_UndeployModelRequest.Merge(m, src)
}
func (m *UndeployModelRequest) XXX_Size() int {
	return xxx_messageInfo_UndeployModelRequest.Size(m)
}
func (m *UndeployModelRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_UndeployModelRequest.DiscardUnknown(m)
}

var xxx_messageInfo_UndeployModelRequest proto.InternalMessageInfo

func (m *UndeployModelRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request message for [AutoMl.ExportModel][google.cloud.automl.v1beta1.AutoMl.ExportModel].
// Models need to be enabled for exporting, otherwise an error code will be
// returned.
type ExportModelRequest struct {
	// Required. The resource name of the model to export.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The desired output location and configuration.
	OutputConfig         *ModelExportOutputConfig `protobuf:"bytes,3,opt,name=output_config,json=outputConfig,proto3" json:"output_config,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                 `json:"-"`
	XXX_unrecognized     []byte                   `json:"-"`
	XXX_sizecache        int32                    `json:"-"`
}

func (m *ExportModelRequest) Reset()         { *m = ExportModelRequest{} }
func (m *ExportModelRequest) String() string { return proto.CompactTextString(m) }
func (*ExportModelRequest) ProtoMessage()    {}
func (*ExportModelRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{24}
}

func (m *ExportModelRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ExportModelRequest.Unmarshal(m, b)
}
func (m *ExportModelRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ExportModelRequest.Marshal(b, m, deterministic)
}
func (m *ExportModelRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ExportModelRequest.Merge(m, src)
}
func (m *ExportModelRequest) XXX_Size() int {
	return xxx_messageInfo_ExportModelRequest.Size(m)
}
func (m *ExportModelRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ExportModelRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ExportModelRequest proto.InternalMessageInfo

func (m *ExportModelRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *ExportModelRequest) GetOutputConfig() *ModelExportOutputConfig {
	if m != nil {
		return m.OutputConfig
	}
	return nil
}

// Request message for [AutoMl.ExportEvaluatedExamples][google.cloud.automl.v1beta1.AutoMl.ExportEvaluatedExamples].
type ExportEvaluatedExamplesRequest struct {
	// Required. The resource name of the model whose evaluated examples are to
	// be exported.
	Name string `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	// Required. The desired output location and configuration.
	OutputConfig         *ExportEvaluatedExamplesOutputConfig `protobuf:"bytes,3,opt,name=output_config,json=outputConfig,proto3" json:"output_config,omitempty"`
	XXX_NoUnkeyedLiteral struct{}                             `json:"-"`
	XXX_unrecognized     []byte                               `json:"-"`
	XXX_sizecache        int32                                `json:"-"`
}

func (m *ExportEvaluatedExamplesRequest) Reset()         { *m = ExportEvaluatedExamplesRequest{} }
func (m *ExportEvaluatedExamplesRequest) String() string { return proto.CompactTextString(m) }
func (*ExportEvaluatedExamplesRequest) ProtoMessage()    {}
func (*ExportEvaluatedExamplesRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{25}
}

func (m *ExportEvaluatedExamplesRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ExportEvaluatedExamplesRequest.Unmarshal(m, b)
}
func (m *ExportEvaluatedExamplesRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ExportEvaluatedExamplesRequest.Marshal(b, m, deterministic)
}
func (m *ExportEvaluatedExamplesRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ExportEvaluatedExamplesRequest.Merge(m, src)
}
func (m *ExportEvaluatedExamplesRequest) XXX_Size() int {
	return xxx_messageInfo_ExportEvaluatedExamplesRequest.Size(m)
}
func (m *ExportEvaluatedExamplesRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ExportEvaluatedExamplesRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ExportEvaluatedExamplesRequest proto.InternalMessageInfo

func (m *ExportEvaluatedExamplesRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

func (m *ExportEvaluatedExamplesRequest) GetOutputConfig() *ExportEvaluatedExamplesOutputConfig {
	if m != nil {
		return m.OutputConfig
	}
	return nil
}

// Request message for [AutoMl.GetModelEvaluation][google.cloud.automl.v1beta1.AutoMl.GetModelEvaluation].
type GetModelEvaluationRequest struct {
	// Resource name for the model evaluation.
	Name                 string   `protobuf:"bytes,1,opt,name=name,proto3" json:"name,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *GetModelEvaluationRequest) Reset()         { *m = GetModelEvaluationRequest{} }
func (m *GetModelEvaluationRequest) String() string { return proto.CompactTextString(m) }
func (*GetModelEvaluationRequest) ProtoMessage()    {}
func (*GetModelEvaluationRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{26}
}

func (m *GetModelEvaluationRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_GetModelEvaluationRequest.Unmarshal(m, b)
}
func (m *GetModelEvaluationRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_GetModelEvaluationRequest.Marshal(b, m, deterministic)
}
func (m *GetModelEvaluationRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_GetModelEvaluationRequest.Merge(m, src)
}
func (m *GetModelEvaluationRequest) XXX_Size() int {
	return xxx_messageInfo_GetModelEvaluationRequest.Size(m)
}
func (m *GetModelEvaluationRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_GetModelEvaluationRequest.DiscardUnknown(m)
}

var xxx_messageInfo_GetModelEvaluationRequest proto.InternalMessageInfo

func (m *GetModelEvaluationRequest) GetName() string {
	if m != nil {
		return m.Name
	}
	return ""
}

// Request message for [AutoMl.ListModelEvaluations][google.cloud.automl.v1beta1.AutoMl.ListModelEvaluations].
type ListModelEvaluationsRequest struct {
	// Resource name of the model to list the model evaluations for.
	// If modelId is set as "-", this will list model evaluations from across all
	// models of the parent location.
	Parent string `protobuf:"bytes,1,opt,name=parent,proto3" json:"parent,omitempty"`
	// An expression for filtering the results of the request.
	//
	//   * `annotation_spec_id` - for =, !=  or existence. See example below for
	//                          the last.
	//
	// Some examples of using the filter are:
	//
	//   * `annotation_spec_id!=4` --> The model evaluation was done for
	//                             annotation spec with ID different than 4.
	//   * `NOT annotation_spec_id:*` --> The model evaluation was done for
	//                                aggregate of all annotation specs.
	Filter string `protobuf:"bytes,3,opt,name=filter,proto3" json:"filter,omitempty"`
	// Requested page size.
	PageSize int32 `protobuf:"varint,4,opt,name=page_size,json=pageSize,proto3" json:"page_size,omitempty"`
	// A token identifying a page of results for the server to return.
	// Typically obtained via
	// [ListModelEvaluationsResponse.next_page_token][google.cloud.automl.v1beta1.ListModelEvaluationsResponse.next_page_token] of the previous
	// [AutoMl.ListModelEvaluations][google.cloud.automl.v1beta1.AutoMl.ListModelEvaluations] call.
	PageToken            string   `protobuf:"bytes,6,opt,name=page_token,json=pageToken,proto3" json:"page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListModelEvaluationsRequest) Reset()         { *m = ListModelEvaluationsRequest{} }
func (m *ListModelEvaluationsRequest) String() string { return proto.CompactTextString(m) }
func (*ListModelEvaluationsRequest) ProtoMessage()    {}
func (*ListModelEvaluationsRequest) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{27}
}

func (m *ListModelEvaluationsRequest) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListModelEvaluationsRequest.Unmarshal(m, b)
}
func (m *ListModelEvaluationsRequest) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListModelEvaluationsRequest.Marshal(b, m, deterministic)
}
func (m *ListModelEvaluationsRequest) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListModelEvaluationsRequest.Merge(m, src)
}
func (m *ListModelEvaluationsRequest) XXX_Size() int {
	return xxx_messageInfo_ListModelEvaluationsRequest.Size(m)
}
func (m *ListModelEvaluationsRequest) XXX_DiscardUnknown() {
	xxx_messageInfo_ListModelEvaluationsRequest.DiscardUnknown(m)
}

var xxx_messageInfo_ListModelEvaluationsRequest proto.InternalMessageInfo

func (m *ListModelEvaluationsRequest) GetParent() string {
	if m != nil {
		return m.Parent
	}
	return ""
}

func (m *ListModelEvaluationsRequest) GetFilter() string {
	if m != nil {
		return m.Filter
	}
	return ""
}

func (m *ListModelEvaluationsRequest) GetPageSize() int32 {
	if m != nil {
		return m.PageSize
	}
	return 0
}

func (m *ListModelEvaluationsRequest) GetPageToken() string {
	if m != nil {
		return m.PageToken
	}
	return ""
}

// Response message for [AutoMl.ListModelEvaluations][google.cloud.automl.v1beta1.AutoMl.ListModelEvaluations].
type ListModelEvaluationsResponse struct {
	// List of model evaluations in the requested page.
	ModelEvaluation []*ModelEvaluation `protobuf:"bytes,1,rep,name=model_evaluation,json=modelEvaluation,proto3" json:"model_evaluation,omitempty"`
	// A token to retrieve next page of results.
	// Pass to the [ListModelEvaluationsRequest.page_token][google.cloud.automl.v1beta1.ListModelEvaluationsRequest.page_token] field of a new
	// [AutoMl.ListModelEvaluations][google.cloud.automl.v1beta1.AutoMl.ListModelEvaluations] request to obtain that page.
	NextPageToken        string   `protobuf:"bytes,2,opt,name=next_page_token,json=nextPageToken,proto3" json:"next_page_token,omitempty"`
	XXX_NoUnkeyedLiteral struct{} `json:"-"`
	XXX_unrecognized     []byte   `json:"-"`
	XXX_sizecache        int32    `json:"-"`
}

func (m *ListModelEvaluationsResponse) Reset()         { *m = ListModelEvaluationsResponse{} }
func (m *ListModelEvaluationsResponse) String() string { return proto.CompactTextString(m) }
func (*ListModelEvaluationsResponse) ProtoMessage()    {}
func (*ListModelEvaluationsResponse) Descriptor() ([]byte, []int) {
	return fileDescriptor_62cd04b8735a9250, []int{28}
}

func (m *ListModelEvaluationsResponse) XXX_Unmarshal(b []byte) error {
	return xxx_messageInfo_ListModelEvaluationsResponse.Unmarshal(m, b)
}
func (m *ListModelEvaluationsResponse) XXX_Marshal(b []byte, deterministic bool) ([]byte, error) {
	return xxx_messageInfo_ListModelEvaluationsResponse.Marshal(b, m, deterministic)
}
func (m *ListModelEvaluationsResponse) XXX_Merge(src proto.Message) {
	xxx_messageInfo_ListModelEvaluationsResponse.Merge(m, src)
}
func (m *ListModelEvaluationsResponse) XXX_Size() int {
	return xxx_messageInfo_ListModelEvaluationsResponse.Size(m)
}
func (m *ListModelEvaluationsResponse) XXX_DiscardUnknown() {
	xxx_messageInfo_ListModelEvaluationsResponse.DiscardUnknown(m)
}

var xxx_messageInfo_ListModelEvaluationsResponse proto.InternalMessageInfo

func (m *ListModelEvaluationsResponse) GetModelEvaluation() []*ModelEvaluation {
	if m != nil {
		return m.ModelEvaluation
	}
	return nil
}

func (m *ListModelEvaluationsResponse) GetNextPageToken() string {
	if m != nil {
		return m.NextPageToken
	}
	return ""
}

func init() {
	proto.RegisterType((*CreateDatasetRequest)(nil), "google.cloud.automl.v1beta1.CreateDatasetRequest")
	proto.RegisterType((*GetDatasetRequest)(nil), "google.cloud.automl.v1beta1.GetDatasetRequest")
	proto.RegisterType((*ListDatasetsRequest)(nil), "google.cloud.automl.v1beta1.ListDatasetsRequest")
	proto.RegisterType((*ListDatasetsResponse)(nil), "google.cloud.automl.v1beta1.ListDatasetsResponse")
	proto.RegisterType((*UpdateDatasetRequest)(nil), "google.cloud.automl.v1beta1.UpdateDatasetRequest")
	proto.RegisterType((*DeleteDatasetRequest)(nil), "google.cloud.automl.v1beta1.DeleteDatasetRequest")
	proto.RegisterType((*ImportDataRequest)(nil), "google.cloud.automl.v1beta1.ImportDataRequest")
	proto.RegisterType((*ExportDataRequest)(nil), "google.cloud.automl.v1beta1.ExportDataRequest")
	proto.RegisterType((*GetAnnotationSpecRequest)(nil), "google.cloud.automl.v1beta1.GetAnnotationSpecRequest")
	proto.RegisterType((*GetTableSpecRequest)(nil), "google.cloud.automl.v1beta1.GetTableSpecRequest")
	proto.RegisterType((*ListTableSpecsRequest)(nil), "google.cloud.automl.v1beta1.ListTableSpecsRequest")
	proto.RegisterType((*ListTableSpecsResponse)(nil), "google.cloud.automl.v1beta1.ListTableSpecsResponse")
	proto.RegisterType((*UpdateTableSpecRequest)(nil), "google.cloud.automl.v1beta1.UpdateTableSpecRequest")
	proto.RegisterType((*GetColumnSpecRequest)(nil), "google.cloud.automl.v1beta1.GetColumnSpecRequest")
	proto.RegisterType((*ListColumnSpecsRequest)(nil), "google.cloud.automl.v1beta1.ListColumnSpecsRequest")
	proto.RegisterType((*ListColumnSpecsResponse)(nil), "google.cloud.automl.v1beta1.ListColumnSpecsResponse")
	proto.RegisterType((*UpdateColumnSpecRequest)(nil), "google.cloud.automl.v1beta1.UpdateColumnSpecRequest")
	proto.RegisterType((*CreateModelRequest)(nil), "google.cloud.automl.v1beta1.CreateModelRequest")
	proto.RegisterType((*GetModelRequest)(nil), "google.cloud.automl.v1beta1.GetModelRequest")
	proto.RegisterType((*ListModelsRequest)(nil), "google.cloud.automl.v1beta1.ListModelsRequest")
	proto.RegisterType((*ListModelsResponse)(nil), "google.cloud.automl.v1beta1.ListModelsResponse")
	proto.RegisterType((*DeleteModelRequest)(nil), "google.cloud.automl.v1beta1.DeleteModelRequest")
	proto.RegisterType((*DeployModelRequest)(nil), "google.cloud.automl.v1beta1.DeployModelRequest")
	proto.RegisterType((*UndeployModelRequest)(nil), "google.cloud.automl.v1beta1.UndeployModelRequest")
	proto.RegisterType((*ExportModelRequest)(nil), "google.cloud.automl.v1beta1.ExportModelRequest")
	proto.RegisterType((*ExportEvaluatedExamplesRequest)(nil), "google.cloud.automl.v1beta1.ExportEvaluatedExamplesRequest")
	proto.RegisterType((*GetModelEvaluationRequest)(nil), "google.cloud.automl.v1beta1.GetModelEvaluationRequest")
	proto.RegisterType((*ListModelEvaluationsRequest)(nil), "google.cloud.automl.v1beta1.ListModelEvaluationsRequest")
	proto.RegisterType((*ListModelEvaluationsResponse)(nil), "google.cloud.automl.v1beta1.ListModelEvaluationsResponse")
}

func init() {
	proto.RegisterFile("google/cloud/automl/v1beta1/service.proto", fileDescriptor_62cd04b8735a9250)
}

var fileDescriptor_62cd04b8735a9250 = []byte{
	// 1851 bytes of a gzipped FileDescriptorProto
	0x1f, 0x8b, 0x08, 0x00, 0x00, 0x00, 0x00, 0x00, 0x02, 0xff, 0xd4, 0x59, 0xcd, 0x6f, 0x1c, 0x49,
	0x15, 0xa7, 0xbc, 0xbb, 0x26, 0x7e, 0x63, 0xe3, 0x75, 0xad, 0xd7, 0xf6, 0xb6, 0x77, 0x17, 0xab,
	0x59, 0x36, 0x5e, 0x6f, 0x76, 0x7a, 0x3d, 0x36, 0x8b, 0x3d, 0xde, 0x8d, 0xe2, 0xaf, 0x4c, 0x9c,
	0xd8, 0x49, 0xe4, 0x24, 0x04, 0x50, 0xd0, 0xa8, 0x3d, 0x53, 0x9e, 0x34, 0xe9, 0xe9, 0x6a, 0xa6,
	0x6b, 0x6c, 0x27, 0x28, 0xe2, 0xeb, 0x94, 0x03, 0xa7, 0x08, 0x2e, 0x04, 0x91, 0x03, 0xca, 0x09,
	0x21, 0x40, 0x9c, 0x41, 0x48, 0x08, 0x89, 0x48, 0x5c, 0xc2, 0x01, 0x71, 0xe3, 0xc0, 0x89, 0xff,
	0x80, 0x1b, 0xea, 0xaa, 0xea, 0x8f, 0x99, 0x6e, 0x77, 0xd7, 0x8c, 0x65, 0x45, 0xdc, 0xa6, 0x67,
	0xde, 0xab, 0xf7, 0x7b, 0x5f, 0xd5, 0xef, 0xf7, 0x06, 0x3e, 0x68, 0x50, 0xda, 0xb0, 0x89, 0x51,
	0xb3, 0x69, 0xbb, 0x6e, 0x98, 0x6d, 0x46, 0x9b, 0xb6, 0x71, 0x30, 0xbf, 0x47, 0x98, 0x39, 0x6f,
	0x78, 0xa4, 0x75, 0x60, 0xd5, 0x48, 0xd1, 0x6d, 0x51, 0x46, 0xf1, 0xb4, 0x10, 0x2d, 0x72, 0xd1,
	0xa2, 0x10, 0x2d, 0x4a, 0x51, 0xed, 0x6d, 0x79, 0x8e, 0xe9, 0x5a, 0x86, 0xe9, 0x38, 0x94, 0x99,
	0xcc, 0xa2, 0x8e, 0x27, 0x54, 0xb5, 0xc5, 0x2c, 0x2b, 0x91, 0x78, 0xd5, 0x35, 0xef, 0xdb, 0xd4,
	0xac, 0x4b, 0xad, 0x79, 0x45, 0x2d, 0xcf, 0x25, 0x35, 0xa9, 0xf2, 0x51, 0x96, 0x4a, 0x8d, 0xda,
	0xed, 0x66, 0x87, 0x78, 0xa6, 0xf7, 0x75, 0x93, 0x99, 0x1e, 0x61, 0x52, 0xf4, 0x6c, 0x96, 0xa8,
	0xd5, 0x34, 0x1b, 0x32, 0x4c, 0xda, 0x7b, 0x99, 0x82, 0x54, 0xe5, 0xb8, 0x26, 0xad, 0x13, 0x5b,
	0x0a, 0x96, 0x72, 0x05, 0xab, 0xe4, 0xc0, 0xb4, 0xdb, 0x3c, 0x14, 0x52, 0xe7, 0x5c, 0x96, 0x0e,
	0x75, 0x49, 0xab, 0x23, 0x39, 0x99, 0xd2, 0xcc, 0xdc, 0xb3, 0x49, 0x3c, 0x64, 0x5f, 0x92, 0xd2,
	0x36, 0x75, 0x1a, 0xad, 0xb6, 0xe3, 0x58, 0x4e, 0x23, 0x79, 0xe4, 0x8c, 0x14, 0xe2, 0x4f, 0x7b,
	0xed, 0x7d, 0x63, 0xdf, 0x22, 0x76, 0xbd, 0xda, 0x34, 0xbd, 0x7b, 0x52, 0x62, 0x32, 0x56, 0x2f,
	0x35, 0xdb, 0x22, 0x8e, 0x8c, 0xb3, 0xee, 0xc0, 0xf8, 0x7a, 0x8b, 0x98, 0x8c, 0x6c, 0x88, 0xf0,
	0xef, 0x92, 0xef, 0xb4, 0x89, 0xc7, 0xf0, 0x04, 0x0c, 0xba, 0x66, 0x8b, 0x38, 0x6c, 0x0a, 0xcd,
	0xa0, 0xd9, 0xa1, 0x5d, 0xf9, 0x84, 0xcf, 0xc3, 0xe7, 0x65, 0xa2, 0xa6, 0x06, 0x66, 0xd0, 0x6c,
	0xa1, 0xf4, 0x5e, 0x31, 0xa3, 0x4e, 0x8b, 0xc1, 0xa9, 0x81, 0x92, 0x7e, 0x16, 0xc6, 0x2a, 0x84,
	0x75, 0x19, 0xc3, 0xf0, 0xaa, 0x63, 0x36, 0x89, 0x34, 0xc5, 0x3f, 0xeb, 0x3f, 0x40, 0xf0, 0xc6,
	0xb6, 0xe5, 0x05, 0xa2, 0x5e, 0x1e, 0xb0, 0x09, 0x18, 0xdc, 0xb7, 0x6c, 0x46, 0x5a, 0x53, 0xaf,
	0x88, 0xef, 0xc5, 0x13, 0x9e, 0x86, 0x21, 0xd7, 0x6c, 0x90, 0xaa, 0x67, 0x3d, 0x20, 0x53, 0xaf,
	0xce, 0xa0, 0xd9, 0xd7, 0x76, 0xcf, 0xf8, 0x5f, 0xdc, 0xb0, 0x1e, 0x10, 0xfc, 0x0e, 0x00, 0xff,
	0x91, 0xd1, 0x7b, 0xc4, 0x99, 0x1a, 0xe4, 0x8a, 0x5c, 0xfc, 0xa6, 0xff, 0x85, 0xfe, 0x7d, 0x04,
	0xe3, 0x9d, 0x18, 0x3c, 0x97, 0x3a, 0x1e, 0xc1, 0x17, 0xe0, 0x8c, 0x74, 0xc8, 0x9b, 0x42, 0x33,
	0xaf, 0x28, 0x87, 0x21, 0xd4, 0xc2, 0xef, 0xc3, 0xa8, 0x43, 0x8e, 0x58, 0x35, 0x66, 0x7e, 0x80,
	0x9b, 0x1f, 0xf1, 0xbf, 0xbe, 0x1e, 0x42, 0x78, 0x8c, 0x60, 0xfc, 0x96, 0x5b, 0x4f, 0x26, 0x28,
	0x96, 0x08, 0xd4, 0x47, 0x22, 0xf0, 0x0a, 0x14, 0xda, 0xfc, 0x5c, 0x5e, 0x26, 0x32, 0x99, 0x5a,
	0x70, 0x46, 0x50, 0x49, 0xc5, 0x8b, 0x7e, 0x25, 0xed, 0x98, 0xde, 0xbd, 0x5d, 0x10, 0xe2, 0xfe,
	0x67, 0x7d, 0x0e, 0xc6, 0x37, 0x88, 0x4d, 0x12, 0xa0, 0xd2, 0x12, 0xc9, 0x60, 0x6c, 0xab, 0xe9,
	0xd2, 0x16, 0x8f, 0x62, 0x86, 0x20, 0xbe, 0x02, 0xc3, 0x96, 0xe3, 0xb6, 0x59, 0xb5, 0x46, 0x9d,
	0x7d, 0xab, 0xc1, 0xf3, 0x58, 0x28, 0xcd, 0x66, 0xba, 0xb5, 0xe5, 0x2b, 0xac, 0x73, 0xf9, 0xdd,
	0x82, 0x15, 0x3d, 0xe8, 0x87, 0x30, 0xb6, 0x79, 0xa4, 0x62, 0xf5, 0x2a, 0x8c, 0xd0, 0x36, 0x4b,
	0x98, 0xfd, 0x20, 0xd3, 0xec, 0x35, 0xae, 0x21, 0xed, 0x0e, 0xd3, 0xd8, 0x93, 0x5e, 0x84, 0xa9,
	0x0a, 0x61, 0xab, 0xe1, 0x75, 0x79, 0xc3, 0x25, 0xb5, 0xac, 0xf0, 0xd4, 0xe1, 0x8d, 0x0a, 0x61,
	0x37, 0xfd, 0xbe, 0xcf, 0x11, 0xc5, 0xcb, 0x00, 0x51, 0x63, 0x2b, 0x64, 0x6c, 0x68, 0x3f, 0xf8,
	0xa8, 0xff, 0x01, 0xc1, 0x9b, 0x7e, 0x25, 0x87, 0x76, 0x72, 0xfb, 0xa9, 0x7f, 0x63, 0xa7, 0xd2,
	0x8a, 0x8f, 0x10, 0x4c, 0x74, 0x3b, 0x20, 0x9b, 0xb1, 0x02, 0x85, 0xe8, 0xda, 0x0c, 0xfa, 0xf1,
	0xfd, 0xcc, 0xfc, 0x45, 0xe1, 0x06, 0x16, 0x1e, 0xa8, 0xdc, 0x93, 0x4f, 0x10, 0x4c, 0x88, 0x9e,
	0x4c, 0xa4, 0x6d, 0x13, 0x20, 0xc2, 0x22, 0x1b, 0x53, 0x15, 0xca, 0x50, 0x08, 0xe5, 0x64, 0xcd,
	0x49, 0x60, 0xbc, 0x42, 0xd8, 0x3a, 0x7f, 0xfb, 0x9e, 0x62, 0x49, 0xfd, 0x51, 0x66, 0x24, 0x32,
	0xf4, 0xff, 0x56, 0x53, 0x3f, 0x46, 0x30, 0x99, 0xf0, 0x40, 0x16, 0xd5, 0x65, 0x18, 0x8e, 0xcd,
	0x2f, 0x41, 0x55, 0x9d, 0xcd, 0x4c, 0x65, 0x2c, 0xe4, 0x85, 0x5a, 0x74, 0xa6, 0x72, 0x5d, 0x3d,
	0x45, 0x30, 0x29, 0xea, 0x2a, 0x99, 0xbc, 0x4b, 0x50, 0x88, 0xe1, 0x91, 0x95, 0xa5, 0x0c, 0x07,
	0x22, 0x38, 0x27, 0xab, 0xad, 0x7d, 0xc0, 0x62, 0x5c, 0xd8, 0xf1, 0x47, 0xa1, 0xbc, 0x7c, 0x2f,
	0xc1, 0x6b, 0x7c, 0x64, 0xe2, 0x89, 0x29, 0x94, 0xf4, 0x4c, 0xb8, 0xe2, 0x44, 0xa1, 0xa0, 0x7f,
	0x19, 0x46, 0x2b, 0x84, 0x75, 0x18, 0x49, 0xbb, 0x3c, 0xbf, 0x07, 0x63, 0x7e, 0x02, 0xb9, 0xdc,
	0x4b, 0x99, 0x10, 0x0e, 0x00, 0xc7, 0x01, 0xc8, 0xe2, 0x09, 0xfd, 0x16, 0x55, 0xa3, 0xee, 0xb7,
	0x72, 0xa9, 0xcc, 0x02, 0x16, 0x2f, 0xe0, 0xdc, 0x10, 0xfd, 0x17, 0xf9, 0xa2, 0xae, 0x4d, 0xef,
	0x77, 0x88, 0xfe, 0x16, 0xc1, 0xc7, 0x7c, 0x8c, 0xae, 0xd2, 0xbd, 0x6f, 0x93, 0x1a, 0xab, 0xd6,
	0x09, 0x23, 0x35, 0x3e, 0xdf, 0x8b, 0x29, 0xb7, 0xce, 0x75, 0x9a, 0xc4, 0x61, 0xd5, 0x26, 0x61,
	0xa6, 0x3f, 0x36, 0xc8, 0x5a, 0xb9, 0x94, 0xfd, 0x46, 0xf6, 0x0f, 0xbd, 0xc6, 0xcf, 0xdc, 0x08,
	0x8e, 0xe4, 0x96, 0x37, 0xc2, 0x03, 0x77, 0xe4, 0x79, 0x97, 0x3e, 0xb7, 0xfb, 0xa1, 0xa5, 0x2e,
	0x9e, 0xe6, 0xde, 0xda, 0x34, 0xbc, 0x75, 0x2c, 0x5e, 0x7f, 0x4c, 0xb9, 0xe5, 0xd4, 0x93, 0xce,
	0xa7, 0xc5, 0xe9, 0x47, 0x08, 0xb0, 0x98, 0x18, 0xf2, 0x44, 0xf1, 0x37, 0xd2, 0x47, 0x86, 0xc5,
	0xfc, 0x34, 0x0b, 0x03, 0x19, 0xd3, 0xc3, 0xcf, 0x10, 0xbc, 0x2b, 0x84, 0x36, 0x05, 0xcb, 0x20,
	0xf5, 0xcd, 0x23, 0xb3, 0xe9, 0xda, 0xc4, 0xcb, 0x42, 0x44, 0xd2, 0x11, 0x5d, 0xc8, 0x44, 0x74,
	0x8c, 0x9d, 0x0c, 0x74, 0x06, 0xbc, 0x15, 0x74, 0xe5, 0x66, 0x48, 0x82, 0xb2, 0x82, 0xfa, 0x08,
	0xc1, 0x74, 0xd8, 0x1f, 0x91, 0xca, 0x4b, 0x69, 0xd5, 0x5f, 0x20, 0x78, 0x3b, 0x1d, 0x8b, 0xec,
	0xda, 0xdb, 0xf0, 0x7a, 0x37, 0xc1, 0x93, 0x0d, 0x7c, 0x4e, 0x21, 0xb3, 0x51, 0x3c, 0x46, 0x9b,
	0x9d, 0x5f, 0xa8, 0x36, 0x75, 0xe9, 0x9f, 0x3a, 0x0c, 0xae, 0xb6, 0x19, 0xdd, 0xb1, 0xf1, 0xaf,
	0x10, 0x8c, 0x74, 0xf0, 0x32, 0x3c, 0x9f, 0x7d, 0xd7, 0xa7, 0x70, 0x38, 0x4d, 0x89, 0x11, 0xe8,
	0x6b, 0x3f, 0xfc, 0xfb, 0xbf, 0x1f, 0x0f, 0x7c, 0xaa, 0xcf, 0x87, 0x24, 0xf4, 0xbb, 0x22, 0x0b,
	0x9f, 0xb9, 0x2d, 0xea, 0xf7, 0xa5, 0x67, 0xcc, 0x19, 0x36, 0xad, 0x89, 0x68, 0x19, 0x73, 0x0f,
	0x03, 0xa6, 0xee, 0x95, 0x43, 0x32, 0xf1, 0x73, 0x04, 0x10, 0xd1, 0x3a, 0x5c, 0xcc, 0x34, 0x9c,
	0xe0, 0x7f, 0x8a, 0x40, 0x97, 0x39, 0xd0, 0x05, 0x1c, 0x03, 0xea, 0x17, 0xd9, 0x31, 0x30, 0x43,
	0x94, 0xc6, 0xdc, 0x43, 0xfc, 0x6b, 0x04, 0xc3, 0x71, 0x22, 0x87, 0x3f, 0xce, 0xb4, 0x98, 0xc2,
	0x3b, 0xb5, 0xf9, 0x1e, 0x34, 0x44, 0x41, 0xa5, 0x01, 0x56, 0x8c, 0x2c, 0xfe, 0x3d, 0x82, 0x91,
	0x0e, 0xda, 0x97, 0x93, 0xff, 0x34, 0x8a, 0xa8, 0x18, 0xd6, 0xcb, 0x1c, 0xe5, 0x46, 0x69, 0x39,
	0x42, 0x19, 0xac, 0x62, 0x14, 0xc3, 0x1b, 0xd5, 0xc1, 0x13, 0x04, 0x23, 0x1d, 0xc4, 0x30, 0x07,
	0x76, 0x1a, 0x89, 0xd4, 0xde, 0x09, 0x54, 0x62, 0x3b, 0x8f, 0xe2, 0xb5, 0x60, 0xe7, 0x11, 0x44,
	0x75, 0xae, 0x8f, 0x32, 0xf8, 0x25, 0x02, 0x88, 0xb8, 0x68, 0x4e, 0x99, 0x26, 0x48, 0x6b, 0x1e,
	0xb0, 0x0a, 0x07, 0xb6, 0xaa, 0x7f, 0xda, 0x33, 0xb0, 0xb2, 0x15, 0xda, 0x2a, 0xa3, 0x39, 0x0e,
	0x33, 0x22, 0xaf, 0x39, 0x30, 0x13, 0x2c, 0xf7, 0x14, 0x61, 0x92, 0xa3, 0x38, 0xcc, 0x3f, 0x23,
	0xbe, 0xcb, 0xe9, 0xa4, 0xba, 0xf8, 0x2b, 0x79, 0xbd, 0x9f, 0x4a, 0x8d, 0xb5, 0x0f, 0x33, 0xd5,
	0x3a, 0x75, 0xf4, 0x2b, 0xdc, 0x85, 0x4d, 0xbc, 0xde, 0xab, 0x0b, 0xb1, 0x35, 0x26, 0x1f, 0xcd,
	0xfd, 0xa2, 0xf8, 0x0d, 0x82, 0xe1, 0x38, 0x03, 0xcf, 0xb9, 0x1b, 0x52, 0xc8, 0xba, 0xa6, 0xc8,
	0xf0, 0xf4, 0x8b, 0x1c, 0xf7, 0x05, 0x7c, 0xbe, 0x67, 0xdc, 0x11, 0x4b, 0xf5, 0x21, 0xff, 0x09,
	0xc1, 0x17, 0x3a, 0xc9, 0x30, 0x2e, 0xe5, 0x5e, 0x4f, 0x09, 0xea, 0xaf, 0x2d, 0xf4, 0xa4, 0x23,
	0x2f, 0xb5, 0x14, 0x1f, 0x32, 0x2f, 0xb5, 0x78, 0x01, 0xc5, 0xdc, 0xc0, 0x7f, 0x43, 0x30, 0xda,
	0x45, 0xa2, 0xf1, 0x82, 0xc2, 0x1d, 0xd7, 0x77, 0xf0, 0xbf, 0xc5, 0x81, 0xdf, 0x2e, 0x6d, 0x45,
	0xc0, 0x63, 0xdb, 0xd6, 0x7e, 0xf2, 0x50, 0x8e, 0x71, 0x7d, 0x3f, 0x27, 0x23, 0x1d, 0xb4, 0x3b,
	0xe7, 0xea, 0x4b, 0xa3, 0xe8, 0x9a, 0x2a, 0xa1, 0xd3, 0x6f, 0x72, 0x67, 0xae, 0xe2, 0xed, 0x13,
	0x55, 0x92, 0x11, 0x63, 0xa9, 0x7e, 0x5d, 0xbd, 0x40, 0x30, 0xda, 0x45, 0x88, 0x71, 0x7e, 0x91,
	0x24, 0x17, 0x00, 0xda, 0x62, 0x6f, 0x4a, 0xb2, 0xb4, 0x52, 0x9c, 0x52, 0x2d, 0xad, 0xce, 0xc4,
	0xc4, 0xfd, 0xc2, 0xff, 0x42, 0xf0, 0x7a, 0x37, 0xab, 0xc6, 0x8b, 0x0a, 0x95, 0x76, 0x82, 0xf4,
	0x34, 0xb9, 0x27, 0x8d, 0xd2, 0xd7, 0x23, 0x4f, 0xe2, 0xff, 0x86, 0x9c, 0x3c, 0x55, 0xe5, 0xf8,
	0x36, 0xc0, 0x1f, 0xbf, 0x0a, 0x31, 0x5a, 0x8e, 0x0d, 0x85, 0x59, 0x31, 0xce, 0x72, 0xf2, 0x5e,
	0x19, 0xe7, 0xb9, 0x3b, 0x4b, 0xba, 0xa1, 0x3c, 0xc8, 0xf0, 0x11, 0xd8, 0x2b, 0x4b, 0x56, 0xfb,
	0x13, 0x04, 0x67, 0x02, 0xe2, 0x80, 0xcf, 0xe5, 0xb5, 0x45, 0x07, 0x32, 0x05, 0xee, 0xac, 0x7f,
	0x95, 0xc3, 0x9b, 0xc7, 0x86, 0x5a, 0x33, 0x08, 0x6c, 0x7e, 0xbd, 0x3f, 0x43, 0x00, 0x11, 0x7d,
	0xcf, 0x79, 0xd1, 0x26, 0x16, 0x0d, 0x9a, 0xa1, 0x2c, 0x2f, 0x0b, 0x3c, 0x05, 0xa8, 0x52, 0x1c,
	0xf1, 0x4f, 0x11, 0x14, 0x62, 0x7c, 0x3f, 0x27, 0xc1, 0xc9, 0xcd, 0x40, 0x5e, 0x82, 0x25, 0xb0,
	0xb9, 0x9e, 0x23, 0xf8, 0x94, 0x03, 0x0b, 0x09, 0x76, 0x2e, 0xb0, 0x6e, 0x2a, 0x9e, 0x07, 0x6c,
	0x95, 0x03, 0x5b, 0xd1, 0x3f, 0xe9, 0x11, 0x58, 0x59, 0xb0, 0x7e, 0x7f, 0x4c, 0x79, 0xe6, 0x8f,
	0xd2, 0xf1, 0x2d, 0x40, 0xde, 0x28, 0x9d, 0xb2, 0x31, 0xc8, 0x83, 0xb9, 0xce, 0x61, 0x7e, 0xa6,
	0x2f, 0xf5, 0x0a, 0xb3, 0xed, 0x44, 0x40, 0xfd, 0x58, 0xc6, 0x36, 0x10, 0x39, 0xb1, 0x4c, 0xee,
	0x2a, 0x4e, 0x2d, 0x96, 0x62, 0xec, 0xf3, 0x21, 0xfe, 0x15, 0xc1, 0xe4, 0x31, 0x6b, 0x03, 0xbc,
	0xd2, 0xcf, 0xb2, 0x41, 0x11, 0xfa, 0x2e, 0x87, 0xbe, 0xad, 0x57, 0xfa, 0x83, 0x9e, 0x30, 0xeb,
	0xfb, 0xf2, 0x17, 0x04, 0x38, 0xb9, 0xcd, 0xc0, 0x9f, 0x28, 0x5d, 0x4f, 0x89, 0xf5, 0x87, 0xd6,
	0xd3, 0x8e, 0x20, 0x20, 0x5d, 0x78, 0xad, 0x37, 0x87, 0x8c, 0xae, 0xd5, 0x02, 0xef, 0xc1, 0x7f,
	0xc8, 0x7f, 0x29, 0xbb, 0x17, 0x1b, 0x78, 0x49, 0xed, 0x7e, 0x4a, 0xee, 0x65, 0xb4, 0xe5, 0x3e,
	0x34, 0xe5, 0x1d, 0x97, 0xe2, 0x59, 0xf6, 0x4b, 0x3c, 0x4c, 0x56, 0xc2, 0x39, 0x6d, 0xeb, 0xf9,
	0xea, 0x9b, 0xd2, 0xb6, 0xc0, 0x63, 0xba, 0x96, 0x57, 0xac, 0xd1, 0xe6, 0x8b, 0xd5, 0xe2, 0x5d,
	0xc6, 0x5c, 0xaf, 0x6c, 0x18, 0x87, 0x87, 0x87, 0x5d, 0x3f, 0x1a, 0x66, 0x9b, 0xdd, 0x15, 0x7f,
	0xaf, 0x7f, 0xe4, 0xda, 0x26, 0xdb, 0xa7, 0xad, 0xe6, 0xda, 0xef, 0x10, 0x7c, 0xb1, 0x46, 0x9b,
	0x59, 0x7e, 0xad, 0x15, 0xc4, 0xf2, 0xe5, 0x7a, 0x8b, 0x32, 0x7a, 0x1d, 0x7d, 0x73, 0x55, 0xca,
	0x36, 0xa8, 0x6d, 0x3a, 0x8d, 0x22, 0x6d, 0x35, 0x8c, 0x06, 0x71, 0xf8, 0x82, 0xdc, 0x88, 0x2c,
	0xa6, 0xfe, 0x8f, 0xbf, 0x22, 0x1e, 0x9f, 0x0f, 0x4c, 0x57, 0xb8, 0xe0, 0x9d, 0x75, 0x5f, 0xe8,
	0x8e, 0x38, 0xff, 0xce, 0xd7, 0x84, 0xd0, 0x7f, 0x06, 0xde, 0x15, 0xbf, 0x96, 0xcb, 0xfc, 0xe7,
	0x72, 0x99, 0xff, 0xbe, 0x5d, 0x2e, 0x4b, 0x81, 0xbd, 0x41, 0x6e, 0x6c, 0xe1, 0x7f, 0x01, 0x00,
	0x00, 0xff, 0xff, 0x87, 0x9a, 0x62, 0x22, 0x36, 0x22, 0x00, 0x00,
}

// Reference imports to suppress errors if they are not otherwise used.
var _ context.Context
var _ grpc.ClientConn

// This is a compile-time assertion to ensure that this generated file
// is compatible with the grpc package it is being compiled against.
const _ = grpc.SupportPackageIsVersion4

// AutoMlClient is the client API for AutoMl service.
//
// For semantics around ctx use and closing/ending streaming RPCs, please refer to https://godoc.org/google.golang.org/grpc#ClientConn.NewStream.
type AutoMlClient interface {
	// Creates a dataset.
	CreateDataset(ctx context.Context, in *CreateDatasetRequest, opts ...grpc.CallOption) (*Dataset, error)
	// Gets a dataset.
	GetDataset(ctx context.Context, in *GetDatasetRequest, opts ...grpc.CallOption) (*Dataset, error)
	// Lists datasets in a project.
	ListDatasets(ctx context.Context, in *ListDatasetsRequest, opts ...grpc.CallOption) (*ListDatasetsResponse, error)
	// Updates a dataset.
	UpdateDataset(ctx context.Context, in *UpdateDatasetRequest, opts ...grpc.CallOption) (*Dataset, error)
	// Deletes a dataset and all of its contents.
	// Returns empty response in the
	// [response][google.longrunning.Operation.response] field when it completes,
	// and `delete_details` in the
	// [metadata][google.longrunning.Operation.metadata] field.
	DeleteDataset(ctx context.Context, in *DeleteDatasetRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
	// Imports data into a dataset.
	// For Tables this method can only be called on an empty Dataset.
	//
	// For Tables:
	// *   A
	// [schema_inference_version][google.cloud.automl.v1beta1.InputConfig.params]
	//     parameter must be explicitly set.
	// Returns an empty response in the
	// [response][google.longrunning.Operation.response] field when it completes.
	ImportData(ctx context.Context, in *ImportDataRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
	// Exports dataset's data to the provided output location.
	// Returns an empty response in the
	// [response][google.longrunning.Operation.response] field when it completes.
	ExportData(ctx context.Context, in *ExportDataRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
	// Gets an annotation spec.
	GetAnnotationSpec(ctx context.Context, in *GetAnnotationSpecRequest, opts ...grpc.CallOption) (*AnnotationSpec, error)
	// Gets a table spec.
	GetTableSpec(ctx context.Context, in *GetTableSpecRequest, opts ...grpc.CallOption) (*TableSpec, error)
	// Lists table specs in a dataset.
	ListTableSpecs(ctx context.Context, in *ListTableSpecsRequest, opts ...grpc.CallOption) (*ListTableSpecsResponse, error)
	// Updates a table spec.
	UpdateTableSpec(ctx context.Context, in *UpdateTableSpecRequest, opts ...grpc.CallOption) (*TableSpec, error)
	// Gets a column spec.
	GetColumnSpec(ctx context.Context, in *GetColumnSpecRequest, opts ...grpc.CallOption) (*ColumnSpec, error)
	// Lists column specs in a table spec.
	ListColumnSpecs(ctx context.Context, in *ListColumnSpecsRequest, opts ...grpc.CallOption) (*ListColumnSpecsResponse, error)
	// Updates a column spec.
	UpdateColumnSpec(ctx context.Context, in *UpdateColumnSpecRequest, opts ...grpc.CallOption) (*ColumnSpec, error)
	// Creates a model.
	// Returns a Model in the [response][google.longrunning.Operation.response]
	// field when it completes.
	// When you create a model, several model evaluations are created for it:
	// a global evaluation, and one evaluation for each annotation spec.
	CreateModel(ctx context.Context, in *CreateModelRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
	// Gets a model.
	GetModel(ctx context.Context, in *GetModelRequest, opts ...grpc.CallOption) (*Model, error)
	// Lists models.
	ListModels(ctx context.Context, in *ListModelsRequest, opts ...grpc.CallOption) (*ListModelsResponse, error)
	// Deletes a model.
	// Returns `google.protobuf.Empty` in the
	// [response][google.longrunning.Operation.response] field when it completes,
	// and `delete_details` in the
	// [metadata][google.longrunning.Operation.metadata] field.
	DeleteModel(ctx context.Context, in *DeleteModelRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
	// Deploys a model. If a model is already deployed, deploying it with the
	// same parameters has no effect. Deploying with different parametrs
	// (as e.g. changing
	//
	// [node_number][google.cloud.automl.v1beta1.ImageObjectDetectionModelDeploymentMetadata.node_number])
	//  will reset the deployment state without pausing the model's availability.
	//
	// Only applicable for Text Classification, Image Object Detection and Tables;
	// all other domains manage deployment automatically.
	//
	// Returns an empty response in the
	// [response][google.longrunning.Operation.response] field when it completes.
	DeployModel(ctx context.Context, in *DeployModelRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
	// Undeploys a model. If the model is not deployed this method has no effect.
	//
	// Only applicable for Text Classification, Image Object Detection and Tables;
	// all other domains manage deployment automatically.
	//
	// Returns an empty response in the
	// [response][google.longrunning.Operation.response] field when it completes.
	UndeployModel(ctx context.Context, in *UndeployModelRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
	// Exports a trained, "export-able", model to a user specified Google Cloud
	// Storage location. A model is considered export-able if and only if it has
	// an export format defined for it in
	//
	// [ModelExportOutputConfig][google.cloud.automl.v1beta1.ModelExportOutputConfig].
	//
	// Returns an empty response in the
	// [response][google.longrunning.Operation.response] field when it completes.
	ExportModel(ctx context.Context, in *ExportModelRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
	// Exports examples on which the model was evaluated (i.e. which were in the
	// TEST set of the dataset the model was created from), together with their
	// ground truth annotations and the annotations created (predicted) by the
	// model.
	// The examples, ground truth and predictions are exported in the state
	// they were at the moment the model was evaluated.
	//
	// This export is available only for 30 days since the model evaluation is
	// created.
	//
	// Currently only available for Tables.
	//
	// Returns an empty response in the
	// [response][google.longrunning.Operation.response] field when it completes.
	ExportEvaluatedExamples(ctx context.Context, in *ExportEvaluatedExamplesRequest, opts ...grpc.CallOption) (*longrunning.Operation, error)
	// Gets a model evaluation.
	GetModelEvaluation(ctx context.Context, in *GetModelEvaluationRequest, opts ...grpc.CallOption) (*ModelEvaluation, error)
	// Lists model evaluations.
	ListModelEvaluations(ctx context.Context, in *ListModelEvaluationsRequest, opts ...grpc.CallOption) (*ListModelEvaluationsResponse, error)
}

type autoMlClient struct {
	cc *grpc.ClientConn
}

func NewAutoMlClient(cc *grpc.ClientConn) AutoMlClient {
	return &autoMlClient{cc}
}

func (c *autoMlClient) CreateDataset(ctx context.Context, in *CreateDatasetRequest, opts ...grpc.CallOption) (*Dataset, error) {
	out := new(Dataset)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/CreateDataset", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) GetDataset(ctx context.Context, in *GetDatasetRequest, opts ...grpc.CallOption) (*Dataset, error) {
	out := new(Dataset)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/GetDataset", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) ListDatasets(ctx context.Context, in *ListDatasetsRequest, opts ...grpc.CallOption) (*ListDatasetsResponse, error) {
	out := new(ListDatasetsResponse)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/ListDatasets", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) UpdateDataset(ctx context.Context, in *UpdateDatasetRequest, opts ...grpc.CallOption) (*Dataset, error) {
	out := new(Dataset)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/UpdateDataset", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) DeleteDataset(ctx context.Context, in *DeleteDatasetRequest, opts ...grpc.CallOption) (*longrunning.Operation, error) {
	out := new(longrunning.Operation)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/DeleteDataset", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) ImportData(ctx context.Context, in *ImportDataRequest, opts ...grpc.CallOption) (*longrunning.Operation, error) {
	out := new(longrunning.Operation)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/ImportData", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) ExportData(ctx context.Context, in *ExportDataRequest, opts ...grpc.CallOption) (*longrunning.Operation, error) {
	out := new(longrunning.Operation)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/ExportData", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) GetAnnotationSpec(ctx context.Context, in *GetAnnotationSpecRequest, opts ...grpc.CallOption) (*AnnotationSpec, error) {
	out := new(AnnotationSpec)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/GetAnnotationSpec", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) GetTableSpec(ctx context.Context, in *GetTableSpecRequest, opts ...grpc.CallOption) (*TableSpec, error) {
	out := new(TableSpec)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/GetTableSpec", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) ListTableSpecs(ctx context.Context, in *ListTableSpecsRequest, opts ...grpc.CallOption) (*ListTableSpecsResponse, error) {
	out := new(ListTableSpecsResponse)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/ListTableSpecs", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) UpdateTableSpec(ctx context.Context, in *UpdateTableSpecRequest, opts ...grpc.CallOption) (*TableSpec, error) {
	out := new(TableSpec)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/UpdateTableSpec", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) GetColumnSpec(ctx context.Context, in *GetColumnSpecRequest, opts ...grpc.CallOption) (*ColumnSpec, error) {
	out := new(ColumnSpec)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/GetColumnSpec", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) ListColumnSpecs(ctx context.Context, in *ListColumnSpecsRequest, opts ...grpc.CallOption) (*ListColumnSpecsResponse, error) {
	out := new(ListColumnSpecsResponse)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/ListColumnSpecs", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) UpdateColumnSpec(ctx context.Context, in *UpdateColumnSpecRequest, opts ...grpc.CallOption) (*ColumnSpec, error) {
	out := new(ColumnSpec)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/UpdateColumnSpec", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) CreateModel(ctx context.Context, in *CreateModelRequest, opts ...grpc.CallOption) (*longrunning.Operation, error) {
	out := new(longrunning.Operation)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/CreateModel", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) GetModel(ctx context.Context, in *GetModelRequest, opts ...grpc.CallOption) (*Model, error) {
	out := new(Model)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/GetModel", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) ListModels(ctx context.Context, in *ListModelsRequest, opts ...grpc.CallOption) (*ListModelsResponse, error) {
	out := new(ListModelsResponse)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/ListModels", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) DeleteModel(ctx context.Context, in *DeleteModelRequest, opts ...grpc.CallOption) (*longrunning.Operation, error) {
	out := new(longrunning.Operation)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/DeleteModel", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) DeployModel(ctx context.Context, in *DeployModelRequest, opts ...grpc.CallOption) (*longrunning.Operation, error) {
	out := new(longrunning.Operation)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/DeployModel", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) UndeployModel(ctx context.Context, in *UndeployModelRequest, opts ...grpc.CallOption) (*longrunning.Operation, error) {
	out := new(longrunning.Operation)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/UndeployModel", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) ExportModel(ctx context.Context, in *ExportModelRequest, opts ...grpc.CallOption) (*longrunning.Operation, error) {
	out := new(longrunning.Operation)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/ExportModel", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) ExportEvaluatedExamples(ctx context.Context, in *ExportEvaluatedExamplesRequest, opts ...grpc.CallOption) (*longrunning.Operation, error) {
	out := new(longrunning.Operation)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/ExportEvaluatedExamples", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) GetModelEvaluation(ctx context.Context, in *GetModelEvaluationRequest, opts ...grpc.CallOption) (*ModelEvaluation, error) {
	out := new(ModelEvaluation)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/GetModelEvaluation", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

func (c *autoMlClient) ListModelEvaluations(ctx context.Context, in *ListModelEvaluationsRequest, opts ...grpc.CallOption) (*ListModelEvaluationsResponse, error) {
	out := new(ListModelEvaluationsResponse)
	err := c.cc.Invoke(ctx, "/google.cloud.automl.v1beta1.AutoMl/ListModelEvaluations", in, out, opts...)
	if err != nil {
		return nil, err
	}
	return out, nil
}

// AutoMlServer is the server API for AutoMl service.
type AutoMlServer interface {
	// Creates a dataset.
	CreateDataset(context.Context, *CreateDatasetRequest) (*Dataset, error)
	// Gets a dataset.
	GetDataset(context.Context, *GetDatasetRequest) (*Dataset, error)
	// Lists datasets in a project.
	ListDatasets(context.Context, *ListDatasetsRequest) (*ListDatasetsResponse, error)
	// Updates a dataset.
	UpdateDataset(context.Context, *UpdateDatasetRequest) (*Dataset, error)
	// Deletes a dataset and all of its contents.
	// Returns empty response in the
	// [response][google.longrunning.Operation.response] field when it completes,
	// and `delete_details` in the
	// [metadata][google.longrunning.Operation.metadata] field.
	DeleteDataset(context.Context, *DeleteDatasetRequest) (*longrunning.Operation, error)
	// Imports data into a dataset.
	// For Tables this method can only be called on an empty Dataset.
	//
	// For Tables:
	// *   A
	// [schema_inference_version][google.cloud.automl.v1beta1.InputConfig.params]
	//     parameter must be explicitly set.
	// Returns an empty response in the
	// [response][google.longrunning.Operation.response] field when it completes.
	ImportData(context.Context, *ImportDataRequest) (*longrunning.Operation, error)
	// Exports dataset's data to the provided output location.
	// Returns an empty response in the
	// [response][google.longrunning.Operation.response] field when it completes.
	ExportData(context.Context, *ExportDataRequest) (*longrunning.Operation, error)
	// Gets an annotation spec.
	GetAnnotationSpec(context.Context, *GetAnnotationSpecRequest) (*AnnotationSpec, error)
	// Gets a table spec.
	GetTableSpec(context.Context, *GetTableSpecRequest) (*TableSpec, error)
	// Lists table specs in a dataset.
	ListTableSpecs(context.Context, *ListTableSpecsRequest) (*ListTableSpecsResponse, error)
	// Updates a table spec.
	UpdateTableSpec(context.Context, *UpdateTableSpecRequest) (*TableSpec, error)
	// Gets a column spec.
	GetColumnSpec(context.Context, *GetColumnSpecRequest) (*ColumnSpec, error)
	// Lists column specs in a table spec.
	ListColumnSpecs(context.Context, *ListColumnSpecsRequest) (*ListColumnSpecsResponse, error)
	// Updates a column spec.
	UpdateColumnSpec(context.Context, *UpdateColumnSpecRequest) (*ColumnSpec, error)
	// Creates a model.
	// Returns a Model in the [response][google.longrunning.Operation.response]
	// field when it completes.
	// When you create a model, several model evaluations are created for it:
	// a global evaluation, and one evaluation for each annotation spec.
	CreateModel(context.Context, *CreateModelRequest) (*longrunning.Operation, error)
	// Gets a model.
	GetModel(context.Context, *GetModelRequest) (*Model, error)
	// Lists models.
	ListModels(context.Context, *ListModelsRequest) (*ListModelsResponse, error)
	// Deletes a model.
	// Returns `google.protobuf.Empty` in the
	// [response][google.longrunning.Operation.response] field when it completes,
	// and `delete_details` in the
	// [metadata][google.longrunning.Operation.metadata] field.
	DeleteModel(context.Context, *DeleteModelRequest) (*longrunning.Operation, error)
	// Deploys a model. If a model is already deployed, deploying it with the
	// same parameters has no effect. Deploying with different parametrs
	// (as e.g. changing
	//
	// [node_number][google.cloud.automl.v1beta1.ImageObjectDetectionModelDeploymentMetadata.node_number])
	//  will reset the deployment state without pausing the model's availability.
	//
	// Only applicable for Text Classification, Image Object Detection and Tables;
	// all other domains manage deployment automatically.
	//
	// Returns an empty response in the
	// [response][google.longrunning.Operation.response] field when it completes.
	DeployModel(context.Context, *DeployModelRequest) (*longrunning.Operation, error)
	// Undeploys a model. If the model is not deployed this method has no effect.
	//
	// Only applicable for Text Classification, Image Object Detection and Tables;
	// all other domains manage deployment automatically.
	//
	// Returns an empty response in the
	// [response][google.longrunning.Operation.response] field when it completes.
	UndeployModel(context.Context, *UndeployModelRequest) (*longrunning.Operation, error)
	// Exports a trained, "export-able", model to a user specified Google Cloud
	// Storage location. A model is considered export-able if and only if it has
	// an export format defined for it in
	//
	// [ModelExportOutputConfig][google.cloud.automl.v1beta1.ModelExportOutputConfig].
	//
	// Returns an empty response in the
	// [response][google.longrunning.Operation.response] field when it completes.
	ExportModel(context.Context, *ExportModelRequest) (*longrunning.Operation, error)
	// Exports examples on which the model was evaluated (i.e. which were in the
	// TEST set of the dataset the model was created from), together with their
	// ground truth annotations and the annotations created (predicted) by the
	// model.
	// The examples, ground truth and predictions are exported in the state
	// they were at the moment the model was evaluated.
	//
	// This export is available only for 30 days since the model evaluation is
	// created.
	//
	// Currently only available for Tables.
	//
	// Returns an empty response in the
	// [response][google.longrunning.Operation.response] field when it completes.
	ExportEvaluatedExamples(context.Context, *ExportEvaluatedExamplesRequest) (*longrunning.Operation, error)
	// Gets a model evaluation.
	GetModelEvaluation(context.Context, *GetModelEvaluationRequest) (*ModelEvaluation, error)
	// Lists model evaluations.
	ListModelEvaluations(context.Context, *ListModelEvaluationsRequest) (*ListModelEvaluationsResponse, error)
}

func RegisterAutoMlServer(s *grpc.Server, srv AutoMlServer) {
	s.RegisterService(&_AutoMl_serviceDesc, srv)
}

func _AutoMl_CreateDataset_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CreateDatasetRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).CreateDataset(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/CreateDataset",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).CreateDataset(ctx, req.(*CreateDatasetRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_GetDataset_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetDatasetRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).GetDataset(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/GetDataset",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).GetDataset(ctx, req.(*GetDatasetRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_ListDatasets_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListDatasetsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).ListDatasets(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/ListDatasets",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).ListDatasets(ctx, req.(*ListDatasetsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_UpdateDataset_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(UpdateDatasetRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).UpdateDataset(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/UpdateDataset",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).UpdateDataset(ctx, req.(*UpdateDatasetRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_DeleteDataset_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(DeleteDatasetRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).DeleteDataset(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/DeleteDataset",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).DeleteDataset(ctx, req.(*DeleteDatasetRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_ImportData_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ImportDataRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).ImportData(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/ImportData",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).ImportData(ctx, req.(*ImportDataRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_ExportData_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ExportDataRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).ExportData(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/ExportData",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).ExportData(ctx, req.(*ExportDataRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_GetAnnotationSpec_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetAnnotationSpecRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).GetAnnotationSpec(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/GetAnnotationSpec",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).GetAnnotationSpec(ctx, req.(*GetAnnotationSpecRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_GetTableSpec_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetTableSpecRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).GetTableSpec(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/GetTableSpec",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).GetTableSpec(ctx, req.(*GetTableSpecRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_ListTableSpecs_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListTableSpecsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).ListTableSpecs(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/ListTableSpecs",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).ListTableSpecs(ctx, req.(*ListTableSpecsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_UpdateTableSpec_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(UpdateTableSpecRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).UpdateTableSpec(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/UpdateTableSpec",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).UpdateTableSpec(ctx, req.(*UpdateTableSpecRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_GetColumnSpec_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetColumnSpecRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).GetColumnSpec(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/GetColumnSpec",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).GetColumnSpec(ctx, req.(*GetColumnSpecRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_ListColumnSpecs_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListColumnSpecsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).ListColumnSpecs(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/ListColumnSpecs",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).ListColumnSpecs(ctx, req.(*ListColumnSpecsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_UpdateColumnSpec_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(UpdateColumnSpecRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).UpdateColumnSpec(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/UpdateColumnSpec",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).UpdateColumnSpec(ctx, req.(*UpdateColumnSpecRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_CreateModel_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(CreateModelRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).CreateModel(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/CreateModel",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).CreateModel(ctx, req.(*CreateModelRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_GetModel_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetModelRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).GetModel(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/GetModel",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).GetModel(ctx, req.(*GetModelRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_ListModels_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListModelsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).ListModels(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/ListModels",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).ListModels(ctx, req.(*ListModelsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_DeleteModel_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(DeleteModelRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).DeleteModel(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/DeleteModel",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).DeleteModel(ctx, req.(*DeleteModelRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_DeployModel_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(DeployModelRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).DeployModel(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/DeployModel",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).DeployModel(ctx, req.(*DeployModelRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_UndeployModel_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(UndeployModelRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).UndeployModel(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/UndeployModel",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).UndeployModel(ctx, req.(*UndeployModelRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_ExportModel_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ExportModelRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).ExportModel(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/ExportModel",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).ExportModel(ctx, req.(*ExportModelRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_ExportEvaluatedExamples_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ExportEvaluatedExamplesRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).ExportEvaluatedExamples(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/ExportEvaluatedExamples",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).ExportEvaluatedExamples(ctx, req.(*ExportEvaluatedExamplesRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_GetModelEvaluation_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(GetModelEvaluationRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).GetModelEvaluation(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/GetModelEvaluation",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).GetModelEvaluation(ctx, req.(*GetModelEvaluationRequest))
	}
	return interceptor(ctx, in, info, handler)
}

func _AutoMl_ListModelEvaluations_Handler(srv interface{}, ctx context.Context, dec func(interface{}) error, interceptor grpc.UnaryServerInterceptor) (interface{}, error) {
	in := new(ListModelEvaluationsRequest)
	if err := dec(in); err != nil {
		return nil, err
	}
	if interceptor == nil {
		return srv.(AutoMlServer).ListModelEvaluations(ctx, in)
	}
	info := &grpc.UnaryServerInfo{
		Server:     srv,
		FullMethod: "/google.cloud.automl.v1beta1.AutoMl/ListModelEvaluations",
	}
	handler := func(ctx context.Context, req interface{}) (interface{}, error) {
		return srv.(AutoMlServer).ListModelEvaluations(ctx, req.(*ListModelEvaluationsRequest))
	}
	return interceptor(ctx, in, info, handler)
}

var _AutoMl_serviceDesc = grpc.ServiceDesc{
	ServiceName: "google.cloud.automl.v1beta1.AutoMl",
	HandlerType: (*AutoMlServer)(nil),
	Methods: []grpc.MethodDesc{
		{
			MethodName: "CreateDataset",
			Handler:    _AutoMl_CreateDataset_Handler,
		},
		{
			MethodName: "GetDataset",
			Handler:    _AutoMl_GetDataset_Handler,
		},
		{
			MethodName: "ListDatasets",
			Handler:    _AutoMl_ListDatasets_Handler,
		},
		{
			MethodName: "UpdateDataset",
			Handler:    _AutoMl_UpdateDataset_Handler,
		},
		{
			MethodName: "DeleteDataset",
			Handler:    _AutoMl_DeleteDataset_Handler,
		},
		{
			MethodName: "ImportData",
			Handler:    _AutoMl_ImportData_Handler,
		},
		{
			MethodName: "ExportData",
			Handler:    _AutoMl_ExportData_Handler,
		},
		{
			MethodName: "GetAnnotationSpec",
			Handler:    _AutoMl_GetAnnotationSpec_Handler,
		},
		{
			MethodName: "GetTableSpec",
			Handler:    _AutoMl_GetTableSpec_Handler,
		},
		{
			MethodName: "ListTableSpecs",
			Handler:    _AutoMl_ListTableSpecs_Handler,
		},
		{
			MethodName: "UpdateTableSpec",
			Handler:    _AutoMl_UpdateTableSpec_Handler,
		},
		{
			MethodName: "GetColumnSpec",
			Handler:    _AutoMl_GetColumnSpec_Handler,
		},
		{
			MethodName: "ListColumnSpecs",
			Handler:    _AutoMl_ListColumnSpecs_Handler,
		},
		{
			MethodName: "UpdateColumnSpec",
			Handler:    _AutoMl_UpdateColumnSpec_Handler,
		},
		{
			MethodName: "CreateModel",
			Handler:    _AutoMl_CreateModel_Handler,
		},
		{
			MethodName: "GetModel",
			Handler:    _AutoMl_GetModel_Handler,
		},
		{
			MethodName: "ListModels",
			Handler:    _AutoMl_ListModels_Handler,
		},
		{
			MethodName: "DeleteModel",
			Handler:    _AutoMl_DeleteModel_Handler,
		},
		{
			MethodName: "DeployModel",
			Handler:    _AutoMl_DeployModel_Handler,
		},
		{
			MethodName: "UndeployModel",
			Handler:    _AutoMl_UndeployModel_Handler,
		},
		{
			MethodName: "ExportModel",
			Handler:    _AutoMl_ExportModel_Handler,
		},
		{
			MethodName: "ExportEvaluatedExamples",
			Handler:    _AutoMl_ExportEvaluatedExamples_Handler,
		},
		{
			MethodName: "GetModelEvaluation",
			Handler:    _AutoMl_GetModelEvaluation_Handler,
		},
		{
			MethodName: "ListModelEvaluations",
			Handler:    _AutoMl_ListModelEvaluations_Handler,
		},
	},
	Streams:  []grpc.StreamDesc{},
	Metadata: "google/cloud/automl/v1beta1/service.proto",
}
